uim.codec.format.UIM_3_1_0_pb2 API documentation
Description: Generated protocol buffer code.

# Module `uim.codec.format.UIM_3_1_0_pb2`

Generated protocol buffer code.

Expand source code

    # -*- coding: utf-8 -*-
    # Generated by the protocol buffer compiler.  DO NOT EDIT!
    # source: UIM_3_1_0.proto
    """Generated protocol buffer code."""
    from google.protobuf.internal import enum_type_wrapper
    from google.protobuf import descriptor as _descriptor
    from google.protobuf import message as _message
    from google.protobuf import reflection as _reflection
    from google.protobuf import symbol_database as _symbol_database
    # @@protoc_insertion_point(imports)

    _sym_db = _symbol_database.Default()

    DESCRIPTOR = _descriptor.FileDescriptor(
      name='UIM_3_1_0.proto',
      package='UIM_3_1_0',
      syntax='proto3',
      serialized_options=b'\n\026com.wacom.ink.protobufB\tUIM_3_1_0H\001P\000\252\002\023Protobuf.WILL_3_1_0\272\002\tWILL3_1_0',
      create_key=_descriptor._internal_create_key,
      serialized_pb=b'\n\x0fUIM_3_1_0.proto\x12\tUIM_3_1_0\"@\n\tRectangle\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\"\xd8\x01\n\x06Matrix\x12\x0b\n\x03m00\x18\x01 \x01(\x02\x12\x0b\n\x03m01\x18\x02 \x01(\x02\x12\x0b\n\x03m02\x18\x03 \x01(\x02\x12\x0b\n\x03m03\x18\x04 \x01(\x02\x12\x0b\n\x03m10\x18\x05 \x01(\x02\x12\x0b\n\x03m11\x18\x06 \x01(\x02\x12\x0b\n\x03m12\x18\x07 \x01(\x02\x12\x0b\n\x03m13\x18\x08 \x01(\x02\x12\x0b\n\x03m20\x18\t \x01(\x02\x12\x0b\n\x03m21\x18\n \x01(\x02\x12\x0b\n\x03m22\x18\x0b \x01(\x02\x12\x0b\n\x03m23\x18\x0c \x01(\x02\x12\x0b\n\x03m30\x18\r \x01(\x02\x12\x0b\n\x03m31\x18\x0e \x01(\x02\x12\x0b\n\x03m32\x18\x0f \x01(\x02\x12\x0b\n\x03m33\x18\x10 \x01(\x02\"`\n\x08Interval\x12\x11\n\tfromIndex\x18\x01 \x01(\r\x12\x0f\n\x07toIndex\x18\x02 \x01(\r\x12\x12\n\nfromTValue\x18\x03 \x01(\x02\x12\x10\n\x08toTValue\x18\x04 \x01(\x02\x12\n\n\x02id\x18\x64 \x01(\x0c\"\xa7\x01\n\x13PathPointProperties\x12\r\n\x05\x63olor\x18\x01 \x01(\x11\x12\x0c\n\x04size\x18\x02 \x01(\x02\x12\x10\n\x08rotation\x18\x03 \x01(\x02\x12\x0e\n\x06scaleX\x18\x04 \x01(\x02\x12\x0e\n\x06scaleY\x18\x05 \x01(\x02\x12\x0e\n\x06scaleZ\x18\x06 \x01(\x02\x12\x0f\n\x07offsetX\x18\x07 \x01(\x02\x12\x0f\n\x07offsetY\x18\x08 \x01(\x02\x12\x0f\n\x07offsetZ\x18\t \x01(\x02\"\'\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"J\n\x0cInputContext\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x15\n\renvironmentID\x18\x02 \x01(\x0c\x12\x17\n\x0fsensorContextID\x18\x03 \x01(\x0c\"B\n\x0b\x45nvironment\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\'\n\nproperties\x18\x02 \x03(\x0b\x32\x13.UIM_3_1_0.Property\"v\n\x10InkInputProvider\x12\n\n\x02id\x18\x01 \x01(\x0c\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x1f.UIM_3_1_0.InkInputProviderType\x12\'\n\nproperties\x18\x03 \x03(\x0b\x32\x13.UIM_3_1_0.Property\"B\n\x0bInputDevice\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\'\n\nproperties\x18\x02 \x03(\x0b\x32\x13.UIM_3_1_0.Property\"\\\n\rSensorContext\x12\n\n\x02id\x18\x01 \x01(\x0c\x12?\n\x15sensorChannelsContext\x18\x02 \x03(\x0b\x32 .UIM_3_1_0.SensorChannelsContext\"\xad\x01\n\x15SensorChannelsContext\x12\n\n\x02id\x18\x01 \x01(\x0c\x12*\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x18.UIM_3_1_0.SensorChannel\x12\x18\n\x10samplingRateHint\x18\x03 \x01(\r\x12\x0f\n\x07latency\x18\x04 \x01(\r\x12\x1a\n\x12inkInputProviderID\x18\x05 \x01(\x0c\x12\x15\n\rinputDeviceID\x18\x06 \x01(\x0c\"\x9a\x01\n\rSensorChannel\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x0c\n\x04type\x18\x02 \x01(\t\x12.\n\x06metric\x18\x03 \x01(\x0e\x32\x1e.UIM_3_1_0.InkSensorMetricType\x12\x12\n\nresolution\x18\x04 \x01(\x01\x12\x0b\n\x03min\x18\x05 \x01(\x02\x12\x0b\n\x03max\x18\x06 \x01(\x02\x12\x11\n\tprecision\x18\x07 \x01(\r\"\x88\x02\n\x10InputContextData\x12.\n\rinputContexts\x18\x01 \x03(\x0b\x32\x17.UIM_3_1_0.InputContext\x12\x36\n\x11inkInputProviders\x18\x02 \x03(\x0b\x32\x1b.UIM_3_1_0.InkInputProvider\x12,\n\x0cinputDevices\x18\x03 \x03(\x0b\x32\x16.UIM_3_1_0.InputDevice\x12,\n\x0c\x65nvironments\x18\x04 \x03(\x0b\x32\x16.UIM_3_1_0.Environment\x12\x30\n\x0esensorContexts\x18\x05 \x03(\x0b\x32\x18.UIM_3_1_0.SensorContext\"6\n\x0b\x43hannelData\x12\x17\n\x0fsensorChannelID\x18\x01 \x01(\x0c\x12\x0e\n\x06values\x18\x02 \x03(\x11\"\x95\x01\n\nSensorData\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x16\n\x0einputContextID\x18\x02 \x01(\x0c\x12\"\n\x05state\x18\x03 \x01(\x0e\x32\x13.UIM_3_1_0.InkState\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\x12,\n\x0c\x64\x61taChannels\x18\x05 \x03(\x0b\x32\x16.UIM_3_1_0.ChannelData\"m\n\tInputData\x12\x35\n\x10inputContextData\x18\x01 \x01(\x0b\x32\x1b.UIM_3_1_0.InputContextData\x12)\n\nsensorData\x18\x02 \x03(\x0b\x32\x15.UIM_3_1_0.SensorData\"q\n\x0e\x42rushPrototype\x12\x0e\n\x06\x63oordX\x18\x01 \x03(\x02\x12\x0e\n\x06\x63oordY\x18\x02 \x03(\x02\x12\x0e\n\x06\x63oordZ\x18\x03 \x03(\x02\x12\x0f\n\x07indices\x18\x04 \x03(\r\x12\x10\n\x08shapeURI\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x02\"Z\n\x0bVectorBrush\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\tprototype\x18\x02 \x03(\x0b\x32\x19.UIM_3_1_0.BrushPrototype\x12\x0f\n\x07spacing\x18\x03 \x01(\x02\"\xb2\x02\n\x0bRasterBrush\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07spacing\x18\x02 \x01(\x02\x12\x12\n\nscattering\x18\x03 \x01(\x02\x12-\n\x0crotationMode\x18\x04 \x01(\x0e\x32\x17.UIM_3_1_0.RotationMode\x12\x14\n\x0cshapeTexture\x18\x05 \x03(\x0c\x12\x17\n\x0fshapeTextureURI\x18\x06 \x03(\t\x12\x13\n\x0b\x66illTexture\x18\x07 \x01(\x0c\x12\x16\n\x0e\x66illTextureURI\x18\x08 \x01(\t\x12\x11\n\tfillWidth\x18\t \x01(\x02\x12\x12\n\nfillHeight\x18\n \x01(\x02\x12\x15\n\rrandomizeFill\x18\x0b \x01(\x08\x12\'\n\tblendMode\x18\x0c \x01(\x0e\x32\x14.UIM_3_1_0.BlendMode\"g\n\x07\x42rushes\x12-\n\rvectorBrushes\x18\x01 \x03(\x0b\x32\x16.UIM_3_1_0.VectorBrush\x12-\n\rrasterBrushes\x18\x02 \x03(\x0b\x32\x16.UIM_3_1_0.RasterBrush\"\xa2\x08\n\x06Stroke\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\x12\n\nprecisions\x18\x02 \x01(\x11\x12\x16\n\x0estartParameter\x18\x03 \x01(\x02\x12\x14\n\x0c\x65ndParameter\x18\x04 \x01(\x02\x12\x32\n\nsplineData\x18\x05 \x01(\x0b\x32\x1c.UIM_3_1_0.Stroke.SplineDataH\x00\x12>\n\x10splineCompressed\x18\x06 \x01(\x0b\x32\".UIM_3_1_0.Stroke.SplineCompressedH\x00\x12\x19\n\x0fpropertiesIndex\x18\x07 \x01(\rH\x01\x12\x39\n\x0fpropertiesValue\x18\x08 \x01(\x0b\x32\x1e.UIM_3_1_0.PathPointPropertiesH\x01\x12\x17\n\rbrushURIIndex\x18\t \x01(\rH\x02\x12\x17\n\rbrushURIValue\x18\n \x01(\tH\x02\x12\x1c\n\x12renderModeURIIndex\x18\x0b \x01(\rH\x03\x12\x1c\n\x12renderModeURIValue\x18\x0c \x01(\tH\x03\x12\x12\n\nrandomSeed\x18\r \x01(\r\x12\x18\n\x10sensorDataOffset\x18\x0e \x01(\r\x12\x14\n\x0csensorDataID\x18\x0f \x01(\x0c\x12\x19\n\x11sensorDataMapping\x18\x10 \x03(\r\x1a\xfb\x01\n\nSplineData\x12\x0f\n\x07splineX\x18\x01 \x03(\x02\x12\x0f\n\x07splineY\x18\x02 \x03(\x02\x12\x0f\n\x07splineZ\x18\x03 \x03(\x02\x12\x0b\n\x03red\x18\x04 \x03(\r\x12\r\n\x05green\x18\x05 \x03(\r\x12\x0c\n\x04\x62lue\x18\x06 \x03(\r\x12\r\n\x05\x61lpha\x18\x07 \x03(\r\x12\x0c\n\x04size\x18\x08 \x03(\x02\x12\x10\n\x08rotation\x18\t \x03(\x02\x12\x0e\n\x06scaleX\x18\n \x03(\x02\x12\x0e\n\x06scaleY\x18\x0b \x03(\x02\x12\x0e\n\x06scaleZ\x18\x0c \x03(\x02\x12\x0f\n\x07offsetX\x18\r \x03(\x02\x12\x0f\n\x07offsetY\x18\x0e \x03(\x02\x12\x0f\n\x07offsetZ\x18\x0f \x03(\x02\x1a\x81\x02\n\x10SplineCompressed\x12\x0f\n\x07splineX\x18\x01 \x03(\x11\x12\x0f\n\x07splineY\x18\x02 \x03(\x11\x12\x0f\n\x07splineZ\x18\x03 \x03(\x11\x12\x0b\n\x03red\x18\x04 \x03(\r\x12\r\n\x05green\x18\x05 \x03(\r\x12\x0c\n\x04\x62lue\x18\x06 \x03(\r\x12\r\n\x05\x61lpha\x18\x07 \x03(\r\x12\x0c\n\x04size\x18\x08 \x03(\x11\x12\x10\n\x08rotation\x18\t \x03(\x11\x12\x0e\n\x06scaleX\x18\n \x03(\x11\x12\x0e\n\x06scaleY\x18\x0b \x03(\x11\x12\x0e\n\x06scaleZ\x18\x0c \x03(\x11\x12\x0f\n\x07offsetX\x18\r \x03(\x11\x12\x0f\n\x07offsetY\x18\x0e \x03(\x11\x12\x0f\n\x07offsetZ\x18\x0f \x03(\x11\x42\x06\n\x04\x64\x61taB\x0c\n\npropertiesB\n\n\x08\x62rushURIB\x0f\n\rrenderModeURI\"\xcb\x01\n\x07InkData\x12\"\n\x07strokes\x18\x01 \x03(\x0b\x32\x11.UIM_3_1_0.Stroke\x12\x17\n\x0funitScaleFactor\x18\x02 \x01(\x02\x12$\n\ttransform\x18\x03 \x01(\x0b\x32\x11.UIM_3_1_0.Matrix\x12\x11\n\tbrushURIs\x18\x04 \x03(\t\x12\x16\n\x0erenderModeURIs\x18\x05 \x03(\t\x12\x32\n\nproperties\x18\x06 \x03(\x0b\x32\x1e.UIM_3_1_0.PathPointProperties\"\x8e\x01\n\x0bTripleStore\x12\x39\n\nstatements\x18\x01 \x03(\x0b\x32%.UIM_3_1_0.TripleStore.SemanticTriple\x1a\x44\n\x0eSemanticTriple\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x11\n\tpredicate\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"5\n\nProperties\x12\'\n\nproperties\x18\x01 \x03(\x0b\x32\x13.UIM_3_1_0.Property\"\x8c\x01\n\x04Node\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\r\x12\x11\n\x07groupID\x18\x02 \x01(\x0cH\x00\x12\x0f\n\x05index\x18\x03 \x01(\rH\x00\x12%\n\x08interval\x18\x04 \x01(\x0b\x32\x13.UIM_3_1_0.Interval\x12$\n\x06\x62ounds\x18\x05 \x01(\x0b\x32\x14.UIM_3_1_0.RectangleB\x04\n\x02id\"6\n\x07InkTree\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x04tree\x18\x02 \x03(\x0b\x32\x0f.UIM_3_1_0.Node\"~\n\x0cInkStructure\x12&\n\x04type\x18\x01 \x01(\x0e\x32\x18.UIM_3_1_0.StructureType\x12#\n\x07inkTree\x18\x02 \x01(\x0b\x32\x12.UIM_3_1_0.InkTree\x12!\n\x05views\x18\x03 \x03(\x0b\x32\x12.UIM_3_1_0.InkTree\"\x14\n\x04Path\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x02\"&\n\x05Paths\x12\x1d\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x0f.UIM_3_1_0.Path\"\xbb\x01\n\x07InkPath\x12 \n\x04type\x18\x01 \x01(\x0e\x32\x12.UIM_3_1_0.InkType\x12\x0e\n\x06layout\x18\x02 \x01(\r\x12\x32\n\npointProps\x18\x03 \x01(\x0b\x32\x1e.UIM_3_1_0.PathPointProperties\x12\x1f\n\x04path\x18\x04 \x01(\x0b\x32\x0f.UIM_3_1_0.PathH\x00\x12!\n\x05paths\x18\x05 \x01(\x0b\x32\x10.UIM_3_1_0.PathsH\x00\x42\x06\n\x04\x64\x61ta\"f\n\x05Style\x12\x11\n\tpointerID\x18\x01 \x01(\r\x12\r\n\x05\x63olor\x18\x02 \x01(\x11\x12\x10\n\x08\x62rushURI\x18\x03 \x01(\t\x12\x12\n\nrandomSeed\x18\x04 \x01(\r\x12\x15\n\rrenderModeURI\x18\x05 \x01(\t\"O\n\x07Segment\x12\x11\n\tpointerID\x18\x01 \x01(\r\x12\x10\n\x08\x63omplete\x18\x02 \x01(\x08\x12\x1f\n\x03ink\x18\x03 \x01(\x0b\x32\x12.UIM_3_1_0.InkPath\"\x1e\n\x0eStrokesContext\x12\x0c\n\x04path\x18\x01 \x03(\x0c\"D\n\x0cIntersection\x12\x0c\n\x04path\x18\x01 \x01(\x0c\x12&\n\tintervals\x18\x02 \x03(\x0b\x32\x13.UIM_3_1_0.Interval\"\xa4\t\n\x0cInkOperation\x12\x32\n\x07\x63ompose\x18\x01 \x01(\x0b\x32\x1f.UIM_3_1_0.InkOperation.ComposeH\x00\x12*\n\x03\x61\x64\x64\x18\x02 \x01(\x0b\x32\x1b.UIM_3_1_0.InkOperation.AddH\x00\x12\x30\n\x06remove\x18\x03 \x01(\x0b\x32\x1e.UIM_3_1_0.InkOperation.RemoveH\x00\x12\x30\n\x06update\x18\x04 \x01(\x0b\x32\x1e.UIM_3_1_0.InkOperation.UpdateH\x00\x12.\n\x05split\x18\x05 \x01(\x0b\x32\x1d.UIM_3_1_0.InkOperation.SplitH\x00\x12\x30\n\x06select\x18\x06 \x01(\x0b\x32\x1e.UIM_3_1_0.InkOperation.SelectH\x00\x12\x42\n\x0fupdateSelection\x18\x07 \x01(\x0b\x32\'.UIM_3_1_0.InkOperation.UpdateSelectionH\x00\x12\x36\n\ttransform\x18\x08 \x01(\x0b\x32!.UIM_3_1_0.InkOperation.TransformH\x00\x1am\n\x07\x43ompose\x12!\n\x05style\x18\x01 \x01(\x0b\x32\x10.UIM_3_1_0.StyleH\x00\x12%\n\x07segment\x18\x02 \x01(\x0b\x32\x12.UIM_3_1_0.SegmentH\x00\x12\x0f\n\x05\x61\x62ort\x18\x03 \x01(\x08H\x00\x42\x07\n\x05stage\x1aG\n\x03\x41\x64\x64\x12\x1f\n\x04path\x18\x01 \x01(\x0b\x32\x11.UIM_3_1_0.Stroke\x12\x1f\n\x03ink\x18\x02 \x01(\x0b\x32\x12.UIM_3_1_0.InkPath\x1a\x34\n\x06Remove\x12*\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x19.UIM_3_1_0.StrokesContext\x1a\x63\n\x06Update\x12*\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x19.UIM_3_1_0.StrokesContext\x12\x1f\n\x05style\x18\x02 \x01(\x0b\x32\x10.UIM_3_1_0.Style\x12\x0c\n\x04\x65\x64it\x18\x03 \x01(\x08\x1a\x63\n\x05Split\x12.\n\rintersections\x18\x01 \x03(\x0b\x32\x17.UIM_3_1_0.Intersection\x12*\n\x0c\x61\x66\x66\x65\x63tedArea\x18\x02 \x01(\x0b\x32\x14.UIM_3_1_0.Rectangle\x1ay\n\x06Select\x12%\n\x08selector\x18\x01 \x01(\x0b\x32\x11.UIM_3_1_0.StrokeH\x00\x12.\n\tselection\x18\x02 \x01(\x0b\x32\x19.UIM_3_1_0.StrokesContextH\x00\x12\x0f\n\x05\x61\x62ort\x18\x03 \x01(\x08H\x00\x42\x07\n\x05stage\x1aV\n\x0fUpdateSelection\x12&\n\ttransform\x18\x01 \x01(\x0b\x32\x11.UIM_3_1_0.MatrixH\x00\x12\x12\n\x08\x63omplete\x18\x02 \x01(\x08H\x00\x42\x07\n\x05stage\x1aZ\n\tTransform\x12*\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x19.UIM_3_1_0.StrokesContext\x12!\n\x06matrix\x18\x02 \x01(\x0b\x32\x11.UIM_3_1_0.MatrixB\x0b\n\toperation\"3\n\x05Range\x12\x0b\n\x03min\x18\x01 \x01(\x02\x12\x0b\n\x03max\x18\x02 \x01(\x02\x12\x10\n\x08remapURI\x18\x03 \x01(\t\"\x86\x01\n\x10PathPointContext\x12/\n\x07statics\x18\x01 \x01(\x0b\x32\x1e.UIM_3_1_0.PathPointProperties\x12.\n\x08\x64ynamics\x18\x02 \x01(\x0b\x32\x1c.UIM_3_1_0.PathPointSettings\x12\x11\n\tcolorMask\x18\x03 \x01(\r\"\xab\x04\n\x11PathPointSettings\x12)\n\x04size\x18\x01 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12(\n\x03red\x18\x02 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12*\n\x05green\x18\x03 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12)\n\x04\x62lue\x18\x04 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12*\n\x05\x61lpha\x18\x05 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12-\n\x08rotation\x18\x06 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12+\n\x06scaleX\x18\x07 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12+\n\x06scaleY\x18\x08 \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12+\n\x06scaleZ\x18\t \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12,\n\x07offsetX\x18\x0b \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12,\n\x07offsetY\x18\x0c \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\x12,\n\x07offsetZ\x18\r \x01(\x0b\x32\x1b.UIM_3_1_0.PropertySettings\"\x8f\x02\n\x10PropertySettings\x12\x1f\n\x05value\x18\x01 \x01(\x0b\x32\x10.UIM_3_1_0.Range\x12\"\n\x08velocity\x18\x02 \x01(\x0b\x32\x10.UIM_3_1_0.Range\x12\"\n\x08pressure\x18\x03 \x01(\x0b\x32\x10.UIM_3_1_0.Range\x12\"\n\x08\x61ltitude\x18\x04 \x01(\x0b\x32\x10.UIM_3_1_0.Range\x12!\n\x07radiusX\x18\x05 \x01(\x0b\x32\x10.UIM_3_1_0.Range\x12!\n\x07radiusY\x18\x06 \x01(\x0b\x32\x10.UIM_3_1_0.Range\x12\x12\n\nresolveURI\x18\x07 \x01(\t\x12\x14\n\x0c\x64\x65pendencies\x18\x08 \x01(\r\"\xc7\x01\n\x07InkTool\x12-\n\x0bvectorBrush\x18\x01 \x01(\x0b\x32\x16.UIM_3_1_0.VectorBrushH\x00\x12-\n\x0brasterBrush\x18\x02 \x01(\x0b\x32\x16.UIM_3_1_0.RasterBrushH\x00\x12\'\n\tblendMode\x18\x03 \x01(\x0e\x32\x14.UIM_3_1_0.BlendMode\x12,\n\x07\x63ontext\x18\x04 \x01(\x0b\x32\x1b.UIM_3_1_0.PathPointContextB\x07\n\x05\x62rush*p\n\tBlendMode\x12\x0f\n\x0bSOURCE_OVER\x10\x00\x12\x14\n\x10\x44\x45STINATION_OVER\x10\x01\x12\x13\n\x0f\x44\x45STINATION_OUT\x10\x02\x12\x0b\n\x07LIGHTER\x10\x03\x12\x08\n\x04\x43OPY\x10\x04\x12\x07\n\x03MIN\x10\x05\x12\x07\n\x03MAX\x10\x06*G\n\x08InkState\x12\t\n\x05PLANE\x10\x00\x12\x0c\n\x08HOVERING\x10\x01\x12\r\n\tIN_VOLUME\x10\x02\x12\x13\n\x0fVOLUME_HOVERING\x10\x03*q\n\x13InkSensorMetricType\x12\n\n\x06LENGTH\x10\x00\x12\x08\n\x04TIME\x10\x01\x12\t\n\x05\x46ORCE\x10\x02\x12\t\n\x05\x41NGLE\x10\x03\x12\x0e\n\nNORMALIZED\x10\x04\x12\x0b\n\x07LOGICAL\x10\x05\x12\x11\n\rDIMENSIONLESS\x10\x06*E\n\x14InkInputProviderType\x12\x07\n\x03PEN\x10\x00\x12\t\n\x05TOUCH\x10\x01\x12\t\n\x05MOUSE\x10\x02\x12\x0e\n\nCONTROLLER\x10\x03*4\n\x0cRotationMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06RANDOM\x10\x01\x12\x0e\n\nTRAJECTORY\x10\x02*,\n\rStructureType\x12\n\n\x06STROKE\x10\x00\x12\x0f\n\x0bSENSOR_DATA\x10\x01*E\n\x07InkType\x12\t\n\x05SHAPE\x10\x00\x12\n\n\x06SHAPES\x10\x01\x12\x17\n\x13INTERPOLATED_SPLINE\x10\x02\x12\n\n\x06SPLINE\x10\x03\x42I\n\x16\x63om.wacom.ink.protobufB\tUIM_3_1_0H\x01P\x00\xaa\x02\x13Protobuf.WILL_3_1_0\xba\x02\tWILL3_1_0b\x06proto3'
    )

    _BLENDMODE = _descriptor.EnumDescriptor(
      name='BlendMode',
      full_name='UIM_3_1_0.BlendMode',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='SOURCE_OVER', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='DESTINATION_OVER', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='DESTINATION_OUT', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='LIGHTER', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='COPY', index=4, number=4,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='MIN', index=5, number=5,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='MAX', index=6, number=6,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7338,
      serialized_end=7450,
    )
    _sym_db.RegisterEnumDescriptor(_BLENDMODE)

    BlendMode = enum_type_wrapper.EnumTypeWrapper(_BLENDMODE)
    _INKSTATE = _descriptor.EnumDescriptor(
      name='InkState',
      full_name='UIM_3_1_0.InkState',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='PLANE', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='HOVERING', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='IN_VOLUME', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='VOLUME_HOVERING', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7452,
      serialized_end=7523,
    )
    _sym_db.RegisterEnumDescriptor(_INKSTATE)

    InkState = enum_type_wrapper.EnumTypeWrapper(_INKSTATE)
    _INKSENSORMETRICTYPE = _descriptor.EnumDescriptor(
      name='InkSensorMetricType',
      full_name='UIM_3_1_0.InkSensorMetricType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='LENGTH', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='TIME', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='FORCE', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='ANGLE', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='NORMALIZED', index=4, number=4,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='LOGICAL', index=5, number=5,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='DIMENSIONLESS', index=6, number=6,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7525,
      serialized_end=7638,
    )
    _sym_db.RegisterEnumDescriptor(_INKSENSORMETRICTYPE)

    InkSensorMetricType = enum_type_wrapper.EnumTypeWrapper(_INKSENSORMETRICTYPE)
    _INKINPUTPROVIDERTYPE = _descriptor.EnumDescriptor(
      name='InkInputProviderType',
      full_name='UIM_3_1_0.InkInputProviderType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='PEN', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='TOUCH', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='MOUSE', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='CONTROLLER', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7640,
      serialized_end=7709,
    )
    _sym_db.RegisterEnumDescriptor(_INKINPUTPROVIDERTYPE)

    InkInputProviderType = enum_type_wrapper.EnumTypeWrapper(_INKINPUTPROVIDERTYPE)
    _ROTATIONMODE = _descriptor.EnumDescriptor(
      name='RotationMode',
      full_name='UIM_3_1_0.RotationMode',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='NONE', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='RANDOM', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='TRAJECTORY', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7711,
      serialized_end=7763,
    )
    _sym_db.RegisterEnumDescriptor(_ROTATIONMODE)

    RotationMode = enum_type_wrapper.EnumTypeWrapper(_ROTATIONMODE)
    _STRUCTURETYPE = _descriptor.EnumDescriptor(
      name='StructureType',
      full_name='UIM_3_1_0.StructureType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='STROKE', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='SENSOR_DATA', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7765,
      serialized_end=7809,
    )
    _sym_db.RegisterEnumDescriptor(_STRUCTURETYPE)

    StructureType = enum_type_wrapper.EnumTypeWrapper(_STRUCTURETYPE)
    _INKTYPE = _descriptor.EnumDescriptor(
      name='InkType',
      full_name='UIM_3_1_0.InkType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='SHAPE', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='SHAPES', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='INTERPOLATED_SPLINE', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='SPLINE', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=7811,
      serialized_end=7880,
    )
    _sym_db.RegisterEnumDescriptor(_INKTYPE)

    InkType = enum_type_wrapper.EnumTypeWrapper(_INKTYPE)
    SOURCE_OVER = 0
    DESTINATION_OVER = 1
    DESTINATION_OUT = 2
    LIGHTER = 3
    COPY = 4
    MIN = 5
    MAX = 6
    PLANE = 0
    HOVERING = 1
    IN_VOLUME = 2
    VOLUME_HOVERING = 3
    LENGTH = 0
    TIME = 1
    FORCE = 2
    ANGLE = 3
    NORMALIZED = 4
    LOGICAL = 5
    DIMENSIONLESS = 6
    PEN = 0
    TOUCH = 1
    MOUSE = 2
    CONTROLLER = 3
    NONE = 0
    RANDOM = 1
    TRAJECTORY = 2
    STROKE = 0
    SENSOR_DATA = 1
    SHAPE = 0
    SHAPES = 1
    INTERPOLATED_SPLINE = 2
    SPLINE = 3

    _RECTANGLE = _descriptor.Descriptor(
      name='Rectangle',
      full_name='UIM_3_1_0.Rectangle',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='x', full_name='UIM_3_1_0.Rectangle.x', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='y', full_name='UIM_3_1_0.Rectangle.y', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='width', full_name='UIM_3_1_0.Rectangle.width', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='height', full_name='UIM_3_1_0.Rectangle.height', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=30,
      serialized_end=94,
    )

    _MATRIX = _descriptor.Descriptor(
      name='Matrix',
      full_name='UIM_3_1_0.Matrix',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='m00', full_name='UIM_3_1_0.Matrix.m00', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m01', full_name='UIM_3_1_0.Matrix.m01', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m02', full_name='UIM_3_1_0.Matrix.m02', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m03', full_name='UIM_3_1_0.Matrix.m03', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m10', full_name='UIM_3_1_0.Matrix.m10', index=4,
          number=5, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m11', full_name='UIM_3_1_0.Matrix.m11', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m12', full_name='UIM_3_1_0.Matrix.m12', index=6,
          number=7, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m13', full_name='UIM_3_1_0.Matrix.m13', index=7,
          number=8, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m20', full_name='UIM_3_1_0.Matrix.m20', index=8,
          number=9, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m21', full_name='UIM_3_1_0.Matrix.m21', index=9,
          number=10, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m22', full_name='UIM_3_1_0.Matrix.m22', index=10,
          number=11, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m23', full_name='UIM_3_1_0.Matrix.m23', index=11,
          number=12, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m30', full_name='UIM_3_1_0.Matrix.m30', index=12,
          number=13, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m31', full_name='UIM_3_1_0.Matrix.m31', index=13,
          number=14, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m32', full_name='UIM_3_1_0.Matrix.m32', index=14,
          number=15, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m33', full_name='UIM_3_1_0.Matrix.m33', index=15,
          number=16, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=97,
      serialized_end=313,
    )

    _INTERVAL = _descriptor.Descriptor(
      name='Interval',
      full_name='UIM_3_1_0.Interval',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='fromIndex', full_name='UIM_3_1_0.Interval.fromIndex', index=0,
          number=1, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='toIndex', full_name='UIM_3_1_0.Interval.toIndex', index=1,
          number=2, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fromTValue', full_name='UIM_3_1_0.Interval.fromTValue', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='toTValue', full_name='UIM_3_1_0.Interval.toTValue', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.Interval.id', index=4,
          number=100, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=315,
      serialized_end=411,
    )

    _PATHPOINTPROPERTIES = _descriptor.Descriptor(
      name='PathPointProperties',
      full_name='UIM_3_1_0.PathPointProperties',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='color', full_name='UIM_3_1_0.PathPointProperties.color', index=0,
          number=1, type=17, cpp_type=1, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='size', full_name='UIM_3_1_0.PathPointProperties.size', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotation', full_name='UIM_3_1_0.PathPointProperties.rotation', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleX', full_name='UIM_3_1_0.PathPointProperties.scaleX', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleY', full_name='UIM_3_1_0.PathPointProperties.scaleY', index=4,
          number=5, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleZ', full_name='UIM_3_1_0.PathPointProperties.scaleZ', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetX', full_name='UIM_3_1_0.PathPointProperties.offsetX', index=6,
          number=7, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetY', full_name='UIM_3_1_0.PathPointProperties.offsetY', index=7,
          number=8, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetZ', full_name='UIM_3_1_0.PathPointProperties.offsetZ', index=8,
          number=9, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=414,
      serialized_end=581,
    )

    _PROPERTY = _descriptor.Descriptor(
      name='Property',
      full_name='UIM_3_1_0.Property',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='UIM_3_1_0.Property.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='value', full_name='UIM_3_1_0.Property.value', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=583,
      serialized_end=622,
    )

    _INPUTCONTEXT = _descriptor.Descriptor(
      name='InputContext',
      full_name='UIM_3_1_0.InputContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.InputContext.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='environmentID', full_name='UIM_3_1_0.InputContext.environmentID', index=1,
          number=2, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorContextID', full_name='UIM_3_1_0.InputContext.sensorContextID', index=2,
          number=3, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=624,
      serialized_end=698,
    )

    _ENVIRONMENT = _descriptor.Descriptor(
      name='Environment',
      full_name='UIM_3_1_0.Environment',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.Environment.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='UIM_3_1_0.Environment.properties', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=700,
      serialized_end=766,
    )

    _INKINPUTPROVIDER = _descriptor.Descriptor(
      name='InkInputProvider',
      full_name='UIM_3_1_0.InkInputProvider',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.InkInputProvider.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='type', full_name='UIM_3_1_0.InkInputProvider.type', index=1,
          number=2, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='UIM_3_1_0.InkInputProvider.properties', index=2,
          number=3, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=768,
      serialized_end=886,
    )

    _INPUTDEVICE = _descriptor.Descriptor(
      name='InputDevice',
      full_name='UIM_3_1_0.InputDevice',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.InputDevice.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='UIM_3_1_0.InputDevice.properties', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=888,
      serialized_end=954,
    )

    _SENSORCONTEXT = _descriptor.Descriptor(
      name='SensorContext',
      full_name='UIM_3_1_0.SensorContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.SensorContext.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorChannelsContext', full_name='UIM_3_1_0.SensorContext.sensorChannelsContext', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=956,
      serialized_end=1048,
    )

    _SENSORCHANNELSCONTEXT = _descriptor.Descriptor(
      name='SensorChannelsContext',
      full_name='UIM_3_1_0.SensorChannelsContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.SensorChannelsContext.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='channels', full_name='UIM_3_1_0.SensorChannelsContext.channels', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='samplingRateHint', full_name='UIM_3_1_0.SensorChannelsContext.samplingRateHint', index=2,
          number=3, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='latency', full_name='UIM_3_1_0.SensorChannelsContext.latency', index=3,
          number=4, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkInputProviderID', full_name='UIM_3_1_0.SensorChannelsContext.inkInputProviderID', index=4,
          number=5, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inputDeviceID', full_name='UIM_3_1_0.SensorChannelsContext.inputDeviceID', index=5,
          number=6, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1051,
      serialized_end=1224,
    )

    _SENSORCHANNEL = _descriptor.Descriptor(
      name='SensorChannel',
      full_name='UIM_3_1_0.SensorChannel',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.SensorChannel.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='type', full_name='UIM_3_1_0.SensorChannel.type', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='metric', full_name='UIM_3_1_0.SensorChannel.metric', index=2,
          number=3, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='resolution', full_name='UIM_3_1_0.SensorChannel.resolution', index=3,
          number=4, type=1, cpp_type=5, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='min', full_name='UIM_3_1_0.SensorChannel.min', index=4,
          number=5, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='max', full_name='UIM_3_1_0.SensorChannel.max', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='precision', full_name='UIM_3_1_0.SensorChannel.precision', index=6,
          number=7, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1227,
      serialized_end=1381,
    )

    _INPUTCONTEXTDATA = _descriptor.Descriptor(
      name='InputContextData',
      full_name='UIM_3_1_0.InputContextData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='inputContexts', full_name='UIM_3_1_0.InputContextData.inputContexts', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkInputProviders', full_name='UIM_3_1_0.InputContextData.inkInputProviders', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inputDevices', full_name='UIM_3_1_0.InputContextData.inputDevices', index=2,
          number=3, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='environments', full_name='UIM_3_1_0.InputContextData.environments', index=3,
          number=4, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorContexts', full_name='UIM_3_1_0.InputContextData.sensorContexts', index=4,
          number=5, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1384,
      serialized_end=1648,
    )

    _CHANNELDATA = _descriptor.Descriptor(
      name='ChannelData',
      full_name='UIM_3_1_0.ChannelData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='sensorChannelID', full_name='UIM_3_1_0.ChannelData.sensorChannelID', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='values', full_name='UIM_3_1_0.ChannelData.values', index=1,
          number=2, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1650,
      serialized_end=1704,
    )

    _SENSORDATA = _descriptor.Descriptor(
      name='SensorData',
      full_name='UIM_3_1_0.SensorData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.SensorData.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inputContextID', full_name='UIM_3_1_0.SensorData.inputContextID', index=1,
          number=2, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='state', full_name='UIM_3_1_0.SensorData.state', index=2,
          number=3, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='timestamp', full_name='UIM_3_1_0.SensorData.timestamp', index=3,
          number=4, type=4, cpp_type=4, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='dataChannels', full_name='UIM_3_1_0.SensorData.dataChannels', index=4,
          number=5, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1707,
      serialized_end=1856,
    )

    _INPUTDATA = _descriptor.Descriptor(
      name='InputData',
      full_name='UIM_3_1_0.InputData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='inputContextData', full_name='UIM_3_1_0.InputData.inputContextData', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorData', full_name='UIM_3_1_0.InputData.sensorData', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1858,
      serialized_end=1967,
    )

    _BRUSHPROTOTYPE = _descriptor.Descriptor(
      name='BrushPrototype',
      full_name='UIM_3_1_0.BrushPrototype',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='coordX', full_name='UIM_3_1_0.BrushPrototype.coordX', index=0,
          number=1, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='coordY', full_name='UIM_3_1_0.BrushPrototype.coordY', index=1,
          number=2, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='coordZ', full_name='UIM_3_1_0.BrushPrototype.coordZ', index=2,
          number=3, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='indices', full_name='UIM_3_1_0.BrushPrototype.indices', index=3,
          number=4, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='shapeURI', full_name='UIM_3_1_0.BrushPrototype.shapeURI', index=4,
          number=5, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='size', full_name='UIM_3_1_0.BrushPrototype.size', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1969,
      serialized_end=2082,
    )

    _VECTORBRUSH = _descriptor.Descriptor(
      name='VectorBrush',
      full_name='UIM_3_1_0.VectorBrush',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='UIM_3_1_0.VectorBrush.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='prototype', full_name='UIM_3_1_0.VectorBrush.prototype', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='spacing', full_name='UIM_3_1_0.VectorBrush.spacing', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2084,
      serialized_end=2174,
    )

    _RASTERBRUSH = _descriptor.Descriptor(
      name='RasterBrush',
      full_name='UIM_3_1_0.RasterBrush',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='UIM_3_1_0.RasterBrush.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='spacing', full_name='UIM_3_1_0.RasterBrush.spacing', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scattering', full_name='UIM_3_1_0.RasterBrush.scattering', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotationMode', full_name='UIM_3_1_0.RasterBrush.rotationMode', index=3,
          number=4, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='shapeTexture', full_name='UIM_3_1_0.RasterBrush.shapeTexture', index=4,
          number=5, type=12, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='shapeTextureURI', full_name='UIM_3_1_0.RasterBrush.shapeTextureURI', index=5,
          number=6, type=9, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillTexture', full_name='UIM_3_1_0.RasterBrush.fillTexture', index=6,
          number=7, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillTextureURI', full_name='UIM_3_1_0.RasterBrush.fillTextureURI', index=7,
          number=8, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillWidth', full_name='UIM_3_1_0.RasterBrush.fillWidth', index=8,
          number=9, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillHeight', full_name='UIM_3_1_0.RasterBrush.fillHeight', index=9,
          number=10, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='randomizeFill', full_name='UIM_3_1_0.RasterBrush.randomizeFill', index=10,
          number=11, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blendMode', full_name='UIM_3_1_0.RasterBrush.blendMode', index=11,
          number=12, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2177,
      serialized_end=2483,
    )

    _BRUSHES = _descriptor.Descriptor(
      name='Brushes',
      full_name='UIM_3_1_0.Brushes',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='vectorBrushes', full_name='UIM_3_1_0.Brushes.vectorBrushes', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rasterBrushes', full_name='UIM_3_1_0.Brushes.rasterBrushes', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2485,
      serialized_end=2588,
    )

    _STROKE_SPLINEDATA = _descriptor.Descriptor(
      name='SplineData',
      full_name='UIM_3_1_0.Stroke.SplineData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='splineX', full_name='UIM_3_1_0.Stroke.SplineData.splineX', index=0,
          number=1, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineY', full_name='UIM_3_1_0.Stroke.SplineData.splineY', index=1,
          number=2, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineZ', full_name='UIM_3_1_0.Stroke.SplineData.splineZ', index=2,
          number=3, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='red', full_name='UIM_3_1_0.Stroke.SplineData.red', index=3,
          number=4, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='green', full_name='UIM_3_1_0.Stroke.SplineData.green', index=4,
          number=5, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blue', full_name='UIM_3_1_0.Stroke.SplineData.blue', index=5,
          number=6, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='alpha', full_name='UIM_3_1_0.Stroke.SplineData.alpha', index=6,
          number=7, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='size', full_name='UIM_3_1_0.Stroke.SplineData.size', index=7,
          number=8, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotation', full_name='UIM_3_1_0.Stroke.SplineData.rotation', index=8,
          number=9, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleX', full_name='UIM_3_1_0.Stroke.SplineData.scaleX', index=9,
          number=10, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleY', full_name='UIM_3_1_0.Stroke.SplineData.scaleY', index=10,
          number=11, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleZ', full_name='UIM_3_1_0.Stroke.SplineData.scaleZ', index=11,
          number=12, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetX', full_name='UIM_3_1_0.Stroke.SplineData.offsetX', index=12,
          number=13, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetY', full_name='UIM_3_1_0.Stroke.SplineData.offsetY', index=13,
          number=14, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetZ', full_name='UIM_3_1_0.Stroke.SplineData.offsetZ', index=14,
          number=15, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3087,
      serialized_end=3338,
    )

    _STROKE_SPLINECOMPRESSED = _descriptor.Descriptor(
      name='SplineCompressed',
      full_name='UIM_3_1_0.Stroke.SplineCompressed',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='splineX', full_name='UIM_3_1_0.Stroke.SplineCompressed.splineX', index=0,
          number=1, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineY', full_name='UIM_3_1_0.Stroke.SplineCompressed.splineY', index=1,
          number=2, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineZ', full_name='UIM_3_1_0.Stroke.SplineCompressed.splineZ', index=2,
          number=3, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='red', full_name='UIM_3_1_0.Stroke.SplineCompressed.red', index=3,
          number=4, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='green', full_name='UIM_3_1_0.Stroke.SplineCompressed.green', index=4,
          number=5, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blue', full_name='UIM_3_1_0.Stroke.SplineCompressed.blue', index=5,
          number=6, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='alpha', full_name='UIM_3_1_0.Stroke.SplineCompressed.alpha', index=6,
          number=7, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='size', full_name='UIM_3_1_0.Stroke.SplineCompressed.size', index=7,
          number=8, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotation', full_name='UIM_3_1_0.Stroke.SplineCompressed.rotation', index=8,
          number=9, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleX', full_name='UIM_3_1_0.Stroke.SplineCompressed.scaleX', index=9,
          number=10, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleY', full_name='UIM_3_1_0.Stroke.SplineCompressed.scaleY', index=10,
          number=11, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleZ', full_name='UIM_3_1_0.Stroke.SplineCompressed.scaleZ', index=11,
          number=12, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetX', full_name='UIM_3_1_0.Stroke.SplineCompressed.offsetX', index=12,
          number=13, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetY', full_name='UIM_3_1_0.Stroke.SplineCompressed.offsetY', index=13,
          number=14, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetZ', full_name='UIM_3_1_0.Stroke.SplineCompressed.offsetZ', index=14,
          number=15, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3341,
      serialized_end=3598,
    )

    _STROKE = _descriptor.Descriptor(
      name='Stroke',
      full_name='UIM_3_1_0.Stroke',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='UIM_3_1_0.Stroke.id', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='precisions', full_name='UIM_3_1_0.Stroke.precisions', index=1,
          number=2, type=17, cpp_type=1, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='startParameter', full_name='UIM_3_1_0.Stroke.startParameter', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='endParameter', full_name='UIM_3_1_0.Stroke.endParameter', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineData', full_name='UIM_3_1_0.Stroke.splineData', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineCompressed', full_name='UIM_3_1_0.Stroke.splineCompressed', index=5,
          number=6, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='propertiesIndex', full_name='UIM_3_1_0.Stroke.propertiesIndex', index=6,
          number=7, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='propertiesValue', full_name='UIM_3_1_0.Stroke.propertiesValue', index=7,
          number=8, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='brushURIIndex', full_name='UIM_3_1_0.Stroke.brushURIIndex', index=8,
          number=9, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='brushURIValue', full_name='UIM_3_1_0.Stroke.brushURIValue', index=9,
          number=10, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='renderModeURIIndex', full_name='UIM_3_1_0.Stroke.renderModeURIIndex', index=10,
          number=11, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='renderModeURIValue', full_name='UIM_3_1_0.Stroke.renderModeURIValue', index=11,
          number=12, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='randomSeed', full_name='UIM_3_1_0.Stroke.randomSeed', index=12,
          number=13, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorDataOffset', full_name='UIM_3_1_0.Stroke.sensorDataOffset', index=13,
          number=14, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorDataID', full_name='UIM_3_1_0.Stroke.sensorDataID', index=14,
          number=15, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorDataMapping', full_name='UIM_3_1_0.Stroke.sensorDataMapping', index=15,
          number=16, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[_STROKE_SPLINEDATA, _STROKE_SPLINECOMPRESSED, ],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='data', full_name='UIM_3_1_0.Stroke.data',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
        _descriptor.OneofDescriptor(
          name='properties', full_name='UIM_3_1_0.Stroke.properties',
          index=1, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
        _descriptor.OneofDescriptor(
          name='brushURI', full_name='UIM_3_1_0.Stroke.brushURI',
          index=2, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
        _descriptor.OneofDescriptor(
          name='renderModeURI', full_name='UIM_3_1_0.Stroke.renderModeURI',
          index=3, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=2591,
      serialized_end=3649,
    )

    _INKDATA = _descriptor.Descriptor(
      name='InkData',
      full_name='UIM_3_1_0.InkData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='strokes', full_name='UIM_3_1_0.InkData.strokes', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='unitScaleFactor', full_name='UIM_3_1_0.InkData.unitScaleFactor', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='transform', full_name='UIM_3_1_0.InkData.transform', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='brushURIs', full_name='UIM_3_1_0.InkData.brushURIs', index=3,
          number=4, type=9, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='renderModeURIs', full_name='UIM_3_1_0.InkData.renderModeURIs', index=4,
          number=5, type=9, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='UIM_3_1_0.InkData.properties', index=5,
          number=6, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3652,
      serialized_end=3855,
    )

    _TRIPLESTORE_SEMANTICTRIPLE = _descriptor.Descriptor(
      name='SemanticTriple',
      full_name='UIM_3_1_0.TripleStore.SemanticTriple',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='subject', full_name='UIM_3_1_0.TripleStore.SemanticTriple.subject', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='predicate', full_name='UIM_3_1_0.TripleStore.SemanticTriple.predicate', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='object', full_name='UIM_3_1_0.TripleStore.SemanticTriple.object', index=2,
          number=3, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3932,
      serialized_end=4000,
    )

    _TRIPLESTORE = _descriptor.Descriptor(
      name='TripleStore',
      full_name='UIM_3_1_0.TripleStore',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='statements', full_name='UIM_3_1_0.TripleStore.statements', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[_TRIPLESTORE_SEMANTICTRIPLE, ],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3858,
      serialized_end=4000,
    )

    _PROPERTIES = _descriptor.Descriptor(
      name='Properties',
      full_name='UIM_3_1_0.Properties',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='properties', full_name='UIM_3_1_0.Properties.properties', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4002,
      serialized_end=4055,
    )

    _NODE = _descriptor.Descriptor(
      name='Node',
      full_name='UIM_3_1_0.Node',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='depth', full_name='UIM_3_1_0.Node.depth', index=0,
          number=1, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='groupID', full_name='UIM_3_1_0.Node.groupID', index=1,
          number=2, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='index', full_name='UIM_3_1_0.Node.index', index=2,
          number=3, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='interval', full_name='UIM_3_1_0.Node.interval', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='bounds', full_name='UIM_3_1_0.Node.bounds', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='id', full_name='UIM_3_1_0.Node.id',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=4058,
      serialized_end=4198,
    )

    _INKTREE = _descriptor.Descriptor(
      name='InkTree',
      full_name='UIM_3_1_0.InkTree',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='UIM_3_1_0.InkTree.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='tree', full_name='UIM_3_1_0.InkTree.tree', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4200,
      serialized_end=4254,
    )

    _INKSTRUCTURE = _descriptor.Descriptor(
      name='InkStructure',
      full_name='UIM_3_1_0.InkStructure',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='type', full_name='UIM_3_1_0.InkStructure.type', index=0,
          number=1, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkTree', full_name='UIM_3_1_0.InkStructure.inkTree', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='views', full_name='UIM_3_1_0.InkStructure.views', index=2,
          number=3, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4256,
      serialized_end=4382,
    )

    _PATH = _descriptor.Descriptor(
      name='Path',
      full_name='UIM_3_1_0.Path',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='data', full_name='UIM_3_1_0.Path.data', index=0,
          number=1, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4384,
      serialized_end=4404,
    )

    _PATHS = _descriptor.Descriptor(
      name='Paths',
      full_name='UIM_3_1_0.Paths',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='data', full_name='UIM_3_1_0.Paths.data', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4406,
      serialized_end=4444,
    )

    _INKPATH = _descriptor.Descriptor(
      name='InkPath',
      full_name='UIM_3_1_0.InkPath',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='type', full_name='UIM_3_1_0.InkPath.type', index=0,
          number=1, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='layout', full_name='UIM_3_1_0.InkPath.layout', index=1,
          number=2, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='pointProps', full_name='UIM_3_1_0.InkPath.pointProps', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='path', full_name='UIM_3_1_0.InkPath.path', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='paths', full_name='UIM_3_1_0.InkPath.paths', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='data', full_name='UIM_3_1_0.InkPath.data',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=4447,
      serialized_end=4634,
    )

    _STYLE = _descriptor.Descriptor(
      name='Style',
      full_name='UIM_3_1_0.Style',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='pointerID', full_name='UIM_3_1_0.Style.pointerID', index=0,
          number=1, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='color', full_name='UIM_3_1_0.Style.color', index=1,
          number=2, type=17, cpp_type=1, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='brushURI', full_name='UIM_3_1_0.Style.brushURI', index=2,
          number=3, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='randomSeed', full_name='UIM_3_1_0.Style.randomSeed', index=3,
          number=4, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='renderModeURI', full_name='UIM_3_1_0.Style.renderModeURI', index=4,
          number=5, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4636,
      serialized_end=4738,
    )

    _SEGMENT = _descriptor.Descriptor(
      name='Segment',
      full_name='UIM_3_1_0.Segment',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='pointerID', full_name='UIM_3_1_0.Segment.pointerID', index=0,
          number=1, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='complete', full_name='UIM_3_1_0.Segment.complete', index=1,
          number=2, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='ink', full_name='UIM_3_1_0.Segment.ink', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4740,
      serialized_end=4819,
    )

    _STROKESCONTEXT = _descriptor.Descriptor(
      name='StrokesContext',
      full_name='UIM_3_1_0.StrokesContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='path', full_name='UIM_3_1_0.StrokesContext.path', index=0,
          number=1, type=12, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4821,
      serialized_end=4851,
    )

    _INTERSECTION = _descriptor.Descriptor(
      name='Intersection',
      full_name='UIM_3_1_0.Intersection',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='path', full_name='UIM_3_1_0.Intersection.path', index=0,
          number=1, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='intervals', full_name='UIM_3_1_0.Intersection.intervals', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4853,
      serialized_end=4921,
    )

    _INKOPERATION_COMPOSE = _descriptor.Descriptor(
      name='Compose',
      full_name='UIM_3_1_0.InkOperation.Compose',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='style', full_name='UIM_3_1_0.InkOperation.Compose.style', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='segment', full_name='UIM_3_1_0.InkOperation.Compose.segment', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='abort', full_name='UIM_3_1_0.InkOperation.Compose.abort', index=2,
          number=3, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='stage', full_name='UIM_3_1_0.InkOperation.Compose.stage',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=5358,
      serialized_end=5467,
    )

    _INKOPERATION_ADD = _descriptor.Descriptor(
      name='Add',
      full_name='UIM_3_1_0.InkOperation.Add',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='path', full_name='UIM_3_1_0.InkOperation.Add.path', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='ink', full_name='UIM_3_1_0.InkOperation.Add.ink', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=5469,
      serialized_end=5540,
    )

    _INKOPERATION_REMOVE = _descriptor.Descriptor(
      name='Remove',
      full_name='UIM_3_1_0.InkOperation.Remove',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='context', full_name='UIM_3_1_0.InkOperation.Remove.context', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=5542,
      serialized_end=5594,
    )

    _INKOPERATION_UPDATE = _descriptor.Descriptor(
      name='Update',
      full_name='UIM_3_1_0.InkOperation.Update',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='context', full_name='UIM_3_1_0.InkOperation.Update.context', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='style', full_name='UIM_3_1_0.InkOperation.Update.style', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='edit', full_name='UIM_3_1_0.InkOperation.Update.edit', index=2,
          number=3, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=5596,
      serialized_end=5695,
    )

    _INKOPERATION_SPLIT = _descriptor.Descriptor(
      name='Split',
      full_name='UIM_3_1_0.InkOperation.Split',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='intersections', full_name='UIM_3_1_0.InkOperation.Split.intersections', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='affectedArea', full_name='UIM_3_1_0.InkOperation.Split.affectedArea', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=5697,
      serialized_end=5796,
    )

    _INKOPERATION_SELECT = _descriptor.Descriptor(
      name='Select',
      full_name='UIM_3_1_0.InkOperation.Select',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='selector', full_name='UIM_3_1_0.InkOperation.Select.selector', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='selection', full_name='UIM_3_1_0.InkOperation.Select.selection', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='abort', full_name='UIM_3_1_0.InkOperation.Select.abort', index=2,
          number=3, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='stage', full_name='UIM_3_1_0.InkOperation.Select.stage',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=5798,
      serialized_end=5919,
    )

    _INKOPERATION_UPDATESELECTION = _descriptor.Descriptor(
      name='UpdateSelection',
      full_name='UIM_3_1_0.InkOperation.UpdateSelection',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='transform', full_name='UIM_3_1_0.InkOperation.UpdateSelection.transform', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='complete', full_name='UIM_3_1_0.InkOperation.UpdateSelection.complete', index=1,
          number=2, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='stage', full_name='UIM_3_1_0.InkOperation.UpdateSelection.stage',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=5921,
      serialized_end=6007,
    )

    _INKOPERATION_TRANSFORM = _descriptor.Descriptor(
      name='Transform',
      full_name='UIM_3_1_0.InkOperation.Transform',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='context', full_name='UIM_3_1_0.InkOperation.Transform.context', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='matrix', full_name='UIM_3_1_0.InkOperation.Transform.matrix', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=6009,
      serialized_end=6099,
    )

    _INKOPERATION = _descriptor.Descriptor(
      name='InkOperation',
      full_name='UIM_3_1_0.InkOperation',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='compose', full_name='UIM_3_1_0.InkOperation.compose', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='add', full_name='UIM_3_1_0.InkOperation.add', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='remove', full_name='UIM_3_1_0.InkOperation.remove', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='update', full_name='UIM_3_1_0.InkOperation.update', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='split', full_name='UIM_3_1_0.InkOperation.split', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='select', full_name='UIM_3_1_0.InkOperation.select', index=5,
          number=6, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='updateSelection', full_name='UIM_3_1_0.InkOperation.updateSelection', index=6,
          number=7, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='transform', full_name='UIM_3_1_0.InkOperation.transform', index=7,
          number=8, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[_INKOPERATION_COMPOSE, _INKOPERATION_ADD, _INKOPERATION_REMOVE, _INKOPERATION_UPDATE, _INKOPERATION_SPLIT, _INKOPERATION_SELECT, _INKOPERATION_UPDATESELECTION, _INKOPERATION_TRANSFORM, ],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='operation', full_name='UIM_3_1_0.InkOperation.operation',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=4924,
      serialized_end=6112,
    )

    _RANGE = _descriptor.Descriptor(
      name='Range',
      full_name='UIM_3_1_0.Range',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='min', full_name='UIM_3_1_0.Range.min', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='max', full_name='UIM_3_1_0.Range.max', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='remapURI', full_name='UIM_3_1_0.Range.remapURI', index=2,
          number=3, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=6114,
      serialized_end=6165,
    )

    _PATHPOINTCONTEXT = _descriptor.Descriptor(
      name='PathPointContext',
      full_name='UIM_3_1_0.PathPointContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='statics', full_name='UIM_3_1_0.PathPointContext.statics', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='dynamics', full_name='UIM_3_1_0.PathPointContext.dynamics', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='colorMask', full_name='UIM_3_1_0.PathPointContext.colorMask', index=2,
          number=3, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=6168,
      serialized_end=6302,
    )

    _PATHPOINTSETTINGS = _descriptor.Descriptor(
      name='PathPointSettings',
      full_name='UIM_3_1_0.PathPointSettings',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='size', full_name='UIM_3_1_0.PathPointSettings.size', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='red', full_name='UIM_3_1_0.PathPointSettings.red', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='green', full_name='UIM_3_1_0.PathPointSettings.green', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blue', full_name='UIM_3_1_0.PathPointSettings.blue', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='alpha', full_name='UIM_3_1_0.PathPointSettings.alpha', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotation', full_name='UIM_3_1_0.PathPointSettings.rotation', index=5,
          number=6, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleX', full_name='UIM_3_1_0.PathPointSettings.scaleX', index=6,
          number=7, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleY', full_name='UIM_3_1_0.PathPointSettings.scaleY', index=7,
          number=8, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleZ', full_name='UIM_3_1_0.PathPointSettings.scaleZ', index=8,
          number=9, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetX', full_name='UIM_3_1_0.PathPointSettings.offsetX', index=9,
          number=11, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetY', full_name='UIM_3_1_0.PathPointSettings.offsetY', index=10,
          number=12, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetZ', full_name='UIM_3_1_0.PathPointSettings.offsetZ', index=11,
          number=13, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=6305,
      serialized_end=6860,
    )

    _PROPERTYSETTINGS = _descriptor.Descriptor(
      name='PropertySettings',
      full_name='UIM_3_1_0.PropertySettings',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='value', full_name='UIM_3_1_0.PropertySettings.value', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='velocity', full_name='UIM_3_1_0.PropertySettings.velocity', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='pressure', full_name='UIM_3_1_0.PropertySettings.pressure', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='altitude', full_name='UIM_3_1_0.PropertySettings.altitude', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='radiusX', full_name='UIM_3_1_0.PropertySettings.radiusX', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='radiusY', full_name='UIM_3_1_0.PropertySettings.radiusY', index=5,
          number=6, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='resolveURI', full_name='UIM_3_1_0.PropertySettings.resolveURI', index=6,
          number=7, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='dependencies', full_name='UIM_3_1_0.PropertySettings.dependencies', index=7,
          number=8, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=6863,
      serialized_end=7134,
    )

    _INKTOOL = _descriptor.Descriptor(
      name='InkTool',
      full_name='UIM_3_1_0.InkTool',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='vectorBrush', full_name='UIM_3_1_0.InkTool.vectorBrush', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rasterBrush', full_name='UIM_3_1_0.InkTool.rasterBrush', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blendMode', full_name='UIM_3_1_0.InkTool.blendMode', index=2,
          number=3, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='context', full_name='UIM_3_1_0.InkTool.context', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
        _descriptor.OneofDescriptor(
          name='brush', full_name='UIM_3_1_0.InkTool.brush',
          index=0, containing_type=None,
          create_key=_descriptor._internal_create_key,
        fields=[]),
      ],
      serialized_start=7137,
      serialized_end=7336,
    )

    _ENVIRONMENT.fields_by_name['properties'].message_type = _PROPERTY
    _INKINPUTPROVIDER.fields_by_name['type'].enum_type = _INKINPUTPROVIDERTYPE
    _INKINPUTPROVIDER.fields_by_name['properties'].message_type = _PROPERTY
    _INPUTDEVICE.fields_by_name['properties'].message_type = _PROPERTY
    _SENSORCONTEXT.fields_by_name['sensorChannelsContext'].message_type = _SENSORCHANNELSCONTEXT
    _SENSORCHANNELSCONTEXT.fields_by_name['channels'].message_type = _SENSORCHANNEL
    _SENSORCHANNEL.fields_by_name['metric'].enum_type = _INKSENSORMETRICTYPE
    _INPUTCONTEXTDATA.fields_by_name['inputContexts'].message_type = _INPUTCONTEXT
    _INPUTCONTEXTDATA.fields_by_name['inkInputProviders'].message_type = _INKINPUTPROVIDER
    _INPUTCONTEXTDATA.fields_by_name['inputDevices'].message_type = _INPUTDEVICE
    _INPUTCONTEXTDATA.fields_by_name['environments'].message_type = _ENVIRONMENT
    _INPUTCONTEXTDATA.fields_by_name['sensorContexts'].message_type = _SENSORCONTEXT
    _SENSORDATA.fields_by_name['state'].enum_type = _INKSTATE
    _SENSORDATA.fields_by_name['dataChannels'].message_type = _CHANNELDATA
    _INPUTDATA.fields_by_name['inputContextData'].message_type = _INPUTCONTEXTDATA
    _INPUTDATA.fields_by_name['sensorData'].message_type = _SENSORDATA
    _VECTORBRUSH.fields_by_name['prototype'].message_type = _BRUSHPROTOTYPE
    _RASTERBRUSH.fields_by_name['rotationMode'].enum_type = _ROTATIONMODE
    _RASTERBRUSH.fields_by_name['blendMode'].enum_type = _BLENDMODE
    _BRUSHES.fields_by_name['vectorBrushes'].message_type = _VECTORBRUSH
    _BRUSHES.fields_by_name['rasterBrushes'].message_type = _RASTERBRUSH
    _STROKE_SPLINEDATA.containing_type = _STROKE
    _STROKE_SPLINECOMPRESSED.containing_type = _STROKE
    _STROKE.fields_by_name['splineData'].message_type = _STROKE_SPLINEDATA
    _STROKE.fields_by_name['splineCompressed'].message_type = _STROKE_SPLINECOMPRESSED
    _STROKE.fields_by_name['propertiesValue'].message_type = _PATHPOINTPROPERTIES
    _STROKE.oneofs_by_name['data'].fields.append(
      _STROKE.fields_by_name['splineData'])
    _STROKE.fields_by_name['splineData'].containing_oneof = _STROKE.oneofs_by_name['data']
    _STROKE.oneofs_by_name['data'].fields.append(
      _STROKE.fields_by_name['splineCompressed'])
    _STROKE.fields_by_name['splineCompressed'].containing_oneof = _STROKE.oneofs_by_name['data']
    _STROKE.oneofs_by_name['properties'].fields.append(
      _STROKE.fields_by_name['propertiesIndex'])
    _STROKE.fields_by_name['propertiesIndex'].containing_oneof = _STROKE.oneofs_by_name['properties']
    _STROKE.oneofs_by_name['properties'].fields.append(
      _STROKE.fields_by_name['propertiesValue'])
    _STROKE.fields_by_name['propertiesValue'].containing_oneof = _STROKE.oneofs_by_name['properties']
    _STROKE.oneofs_by_name['brushURI'].fields.append(
      _STROKE.fields_by_name['brushURIIndex'])
    _STROKE.fields_by_name['brushURIIndex'].containing_oneof = _STROKE.oneofs_by_name['brushURI']
    _STROKE.oneofs_by_name['brushURI'].fields.append(
      _STROKE.fields_by_name['brushURIValue'])
    _STROKE.fields_by_name['brushURIValue'].containing_oneof = _STROKE.oneofs_by_name['brushURI']
    _STROKE.oneofs_by_name['renderModeURI'].fields.append(
      _STROKE.fields_by_name['renderModeURIIndex'])
    _STROKE.fields_by_name['renderModeURIIndex'].containing_oneof = _STROKE.oneofs_by_name['renderModeURI']
    _STROKE.oneofs_by_name['renderModeURI'].fields.append(
      _STROKE.fields_by_name['renderModeURIValue'])
    _STROKE.fields_by_name['renderModeURIValue'].containing_oneof = _STROKE.oneofs_by_name['renderModeURI']
    _INKDATA.fields_by_name['strokes'].message_type = _STROKE
    _INKDATA.fields_by_name['transform'].message_type = _MATRIX
    _INKDATA.fields_by_name['properties'].message_type = _PATHPOINTPROPERTIES
    _TRIPLESTORE_SEMANTICTRIPLE.containing_type = _TRIPLESTORE
    _TRIPLESTORE.fields_by_name['statements'].message_type = _TRIPLESTORE_SEMANTICTRIPLE
    _PROPERTIES.fields_by_name['properties'].message_type = _PROPERTY
    _NODE.fields_by_name['interval'].message_type = _INTERVAL
    _NODE.fields_by_name['bounds'].message_type = _RECTANGLE
    _NODE.oneofs_by_name['id'].fields.append(
      _NODE.fields_by_name['groupID'])
    _NODE.fields_by_name['groupID'].containing_oneof = _NODE.oneofs_by_name['id']
    _NODE.oneofs_by_name['id'].fields.append(
      _NODE.fields_by_name['index'])
    _NODE.fields_by_name['index'].containing_oneof = _NODE.oneofs_by_name['id']
    _INKTREE.fields_by_name['tree'].message_type = _NODE
    _INKSTRUCTURE.fields_by_name['type'].enum_type = _STRUCTURETYPE
    _INKSTRUCTURE.fields_by_name['inkTree'].message_type = _INKTREE
    _INKSTRUCTURE.fields_by_name['views'].message_type = _INKTREE
    _PATHS.fields_by_name['data'].message_type = _PATH
    _INKPATH.fields_by_name['type'].enum_type = _INKTYPE
    _INKPATH.fields_by_name['pointProps'].message_type = _PATHPOINTPROPERTIES
    _INKPATH.fields_by_name['path'].message_type = _PATH
    _INKPATH.fields_by_name['paths'].message_type = _PATHS
    _INKPATH.oneofs_by_name['data'].fields.append(
      _INKPATH.fields_by_name['path'])
    _INKPATH.fields_by_name['path'].containing_oneof = _INKPATH.oneofs_by_name['data']
    _INKPATH.oneofs_by_name['data'].fields.append(
      _INKPATH.fields_by_name['paths'])
    _INKPATH.fields_by_name['paths'].containing_oneof = _INKPATH.oneofs_by_name['data']
    _SEGMENT.fields_by_name['ink'].message_type = _INKPATH
    _INTERSECTION.fields_by_name['intervals'].message_type = _INTERVAL
    _INKOPERATION_COMPOSE.fields_by_name['style'].message_type = _STYLE
    _INKOPERATION_COMPOSE.fields_by_name['segment'].message_type = _SEGMENT
    _INKOPERATION_COMPOSE.containing_type = _INKOPERATION
    _INKOPERATION_COMPOSE.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_COMPOSE.fields_by_name['style'])
    _INKOPERATION_COMPOSE.fields_by_name['style'].containing_oneof = _INKOPERATION_COMPOSE.oneofs_by_name['stage']
    _INKOPERATION_COMPOSE.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_COMPOSE.fields_by_name['segment'])
    _INKOPERATION_COMPOSE.fields_by_name['segment'].containing_oneof = _INKOPERATION_COMPOSE.oneofs_by_name['stage']
    _INKOPERATION_COMPOSE.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_COMPOSE.fields_by_name['abort'])
    _INKOPERATION_COMPOSE.fields_by_name['abort'].containing_oneof = _INKOPERATION_COMPOSE.oneofs_by_name['stage']
    _INKOPERATION_ADD.fields_by_name['path'].message_type = _STROKE
    _INKOPERATION_ADD.fields_by_name['ink'].message_type = _INKPATH
    _INKOPERATION_ADD.containing_type = _INKOPERATION
    _INKOPERATION_REMOVE.fields_by_name['context'].message_type = _STROKESCONTEXT
    _INKOPERATION_REMOVE.containing_type = _INKOPERATION
    _INKOPERATION_UPDATE.fields_by_name['context'].message_type = _STROKESCONTEXT
    _INKOPERATION_UPDATE.fields_by_name['style'].message_type = _STYLE
    _INKOPERATION_UPDATE.containing_type = _INKOPERATION
    _INKOPERATION_SPLIT.fields_by_name['intersections'].message_type = _INTERSECTION
    _INKOPERATION_SPLIT.fields_by_name['affectedArea'].message_type = _RECTANGLE
    _INKOPERATION_SPLIT.containing_type = _INKOPERATION
    _INKOPERATION_SELECT.fields_by_name['selector'].message_type = _STROKE
    _INKOPERATION_SELECT.fields_by_name['selection'].message_type = _STROKESCONTEXT
    _INKOPERATION_SELECT.containing_type = _INKOPERATION
    _INKOPERATION_SELECT.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_SELECT.fields_by_name['selector'])
    _INKOPERATION_SELECT.fields_by_name['selector'].containing_oneof = _INKOPERATION_SELECT.oneofs_by_name['stage']
    _INKOPERATION_SELECT.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_SELECT.fields_by_name['selection'])
    _INKOPERATION_SELECT.fields_by_name['selection'].containing_oneof = _INKOPERATION_SELECT.oneofs_by_name['stage']
    _INKOPERATION_SELECT.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_SELECT.fields_by_name['abort'])
    _INKOPERATION_SELECT.fields_by_name['abort'].containing_oneof = _INKOPERATION_SELECT.oneofs_by_name['stage']
    _INKOPERATION_UPDATESELECTION.fields_by_name['transform'].message_type = _MATRIX
    _INKOPERATION_UPDATESELECTION.containing_type = _INKOPERATION
    _INKOPERATION_UPDATESELECTION.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_UPDATESELECTION.fields_by_name['transform'])
    _INKOPERATION_UPDATESELECTION.fields_by_name['transform'].containing_oneof = _INKOPERATION_UPDATESELECTION.oneofs_by_name['stage']
    _INKOPERATION_UPDATESELECTION.oneofs_by_name['stage'].fields.append(
      _INKOPERATION_UPDATESELECTION.fields_by_name['complete'])
    _INKOPERATION_UPDATESELECTION.fields_by_name['complete'].containing_oneof = _INKOPERATION_UPDATESELECTION.oneofs_by_name['stage']
    _INKOPERATION_TRANSFORM.fields_by_name['context'].message_type = _STROKESCONTEXT
    _INKOPERATION_TRANSFORM.fields_by_name['matrix'].message_type = _MATRIX
    _INKOPERATION_TRANSFORM.containing_type = _INKOPERATION
    _INKOPERATION.fields_by_name['compose'].message_type = _INKOPERATION_COMPOSE
    _INKOPERATION.fields_by_name['add'].message_type = _INKOPERATION_ADD
    _INKOPERATION.fields_by_name['remove'].message_type = _INKOPERATION_REMOVE
    _INKOPERATION.fields_by_name['update'].message_type = _INKOPERATION_UPDATE
    _INKOPERATION.fields_by_name['split'].message_type = _INKOPERATION_SPLIT
    _INKOPERATION.fields_by_name['select'].message_type = _INKOPERATION_SELECT
    _INKOPERATION.fields_by_name['updateSelection'].message_type = _INKOPERATION_UPDATESELECTION
    _INKOPERATION.fields_by_name['transform'].message_type = _INKOPERATION_TRANSFORM
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['compose'])
    _INKOPERATION.fields_by_name['compose'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['add'])
    _INKOPERATION.fields_by_name['add'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['remove'])
    _INKOPERATION.fields_by_name['remove'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['update'])
    _INKOPERATION.fields_by_name['update'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['split'])
    _INKOPERATION.fields_by_name['split'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['select'])
    _INKOPERATION.fields_by_name['select'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['updateSelection'])
    _INKOPERATION.fields_by_name['updateSelection'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _INKOPERATION.oneofs_by_name['operation'].fields.append(
      _INKOPERATION.fields_by_name['transform'])
    _INKOPERATION.fields_by_name['transform'].containing_oneof = _INKOPERATION.oneofs_by_name['operation']
    _PATHPOINTCONTEXT.fields_by_name['statics'].message_type = _PATHPOINTPROPERTIES
    _PATHPOINTCONTEXT.fields_by_name['dynamics'].message_type = _PATHPOINTSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['size'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['red'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['green'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['blue'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['alpha'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['rotation'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['scaleX'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['scaleY'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['scaleZ'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['offsetX'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['offsetY'].message_type = _PROPERTYSETTINGS
    _PATHPOINTSETTINGS.fields_by_name['offsetZ'].message_type = _PROPERTYSETTINGS
    _PROPERTYSETTINGS.fields_by_name['value'].message_type = _RANGE
    _PROPERTYSETTINGS.fields_by_name['velocity'].message_type = _RANGE
    _PROPERTYSETTINGS.fields_by_name['pressure'].message_type = _RANGE
    _PROPERTYSETTINGS.fields_by_name['altitude'].message_type = _RANGE
    _PROPERTYSETTINGS.fields_by_name['radiusX'].message_type = _RANGE
    _PROPERTYSETTINGS.fields_by_name['radiusY'].message_type = _RANGE
    _INKTOOL.fields_by_name['vectorBrush'].message_type = _VECTORBRUSH
    _INKTOOL.fields_by_name['rasterBrush'].message_type = _RASTERBRUSH
    _INKTOOL.fields_by_name['blendMode'].enum_type = _BLENDMODE
    _INKTOOL.fields_by_name['context'].message_type = _PATHPOINTCONTEXT
    _INKTOOL.oneofs_by_name['brush'].fields.append(
      _INKTOOL.fields_by_name['vectorBrush'])
    _INKTOOL.fields_by_name['vectorBrush'].containing_oneof = _INKTOOL.oneofs_by_name['brush']
    _INKTOOL.oneofs_by_name['brush'].fields.append(
      _INKTOOL.fields_by_name['rasterBrush'])
    _INKTOOL.fields_by_name['rasterBrush'].containing_oneof = _INKTOOL.oneofs_by_name['brush']
    DESCRIPTOR.message_types_by_name['Rectangle'] = _RECTANGLE
    DESCRIPTOR.message_types_by_name['Matrix'] = _MATRIX
    DESCRIPTOR.message_types_by_name['Interval'] = _INTERVAL
    DESCRIPTOR.message_types_by_name['PathPointProperties'] = _PATHPOINTPROPERTIES
    DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
    DESCRIPTOR.message_types_by_name['InputContext'] = _INPUTCONTEXT
    DESCRIPTOR.message_types_by_name['Environment'] = _ENVIRONMENT
    DESCRIPTOR.message_types_by_name['InkInputProvider'] = _INKINPUTPROVIDER
    DESCRIPTOR.message_types_by_name['InputDevice'] = _INPUTDEVICE
    DESCRIPTOR.message_types_by_name['SensorContext'] = _SENSORCONTEXT
    DESCRIPTOR.message_types_by_name['SensorChannelsContext'] = _SENSORCHANNELSCONTEXT
    DESCRIPTOR.message_types_by_name['SensorChannel'] = _SENSORCHANNEL
    DESCRIPTOR.message_types_by_name['InputContextData'] = _INPUTCONTEXTDATA
    DESCRIPTOR.message_types_by_name['ChannelData'] = _CHANNELDATA
    DESCRIPTOR.message_types_by_name['SensorData'] = _SENSORDATA
    DESCRIPTOR.message_types_by_name['InputData'] = _INPUTDATA
    DESCRIPTOR.message_types_by_name['BrushPrototype'] = _BRUSHPROTOTYPE
    DESCRIPTOR.message_types_by_name['VectorBrush'] = _VECTORBRUSH
    DESCRIPTOR.message_types_by_name['RasterBrush'] = _RASTERBRUSH
    DESCRIPTOR.message_types_by_name['Brushes'] = _BRUSHES
    DESCRIPTOR.message_types_by_name['Stroke'] = _STROKE
    DESCRIPTOR.message_types_by_name['InkData'] = _INKDATA
    DESCRIPTOR.message_types_by_name['TripleStore'] = _TRIPLESTORE
    DESCRIPTOR.message_types_by_name['Properties'] = _PROPERTIES
    DESCRIPTOR.message_types_by_name['Node'] = _NODE
    DESCRIPTOR.message_types_by_name['InkTree'] = _INKTREE
    DESCRIPTOR.message_types_by_name['InkStructure'] = _INKSTRUCTURE
    DESCRIPTOR.message_types_by_name['Path'] = _PATH
    DESCRIPTOR.message_types_by_name['Paths'] = _PATHS
    DESCRIPTOR.message_types_by_name['InkPath'] = _INKPATH
    DESCRIPTOR.message_types_by_name['Style'] = _STYLE
    DESCRIPTOR.message_types_by_name['Segment'] = _SEGMENT
    DESCRIPTOR.message_types_by_name['StrokesContext'] = _STROKESCONTEXT
    DESCRIPTOR.message_types_by_name['Intersection'] = _INTERSECTION
    DESCRIPTOR.message_types_by_name['InkOperation'] = _INKOPERATION
    DESCRIPTOR.message_types_by_name['Range'] = _RANGE
    DESCRIPTOR.message_types_by_name['PathPointContext'] = _PATHPOINTCONTEXT
    DESCRIPTOR.message_types_by_name['PathPointSettings'] = _PATHPOINTSETTINGS
    DESCRIPTOR.message_types_by_name['PropertySettings'] = _PROPERTYSETTINGS
    DESCRIPTOR.message_types_by_name['InkTool'] = _INKTOOL
    DESCRIPTOR.enum_types_by_name['BlendMode'] = _BLENDMODE
    DESCRIPTOR.enum_types_by_name['InkState'] = _INKSTATE
    DESCRIPTOR.enum_types_by_name['InkSensorMetricType'] = _INKSENSORMETRICTYPE
    DESCRIPTOR.enum_types_by_name['InkInputProviderType'] = _INKINPUTPROVIDERTYPE
    DESCRIPTOR.enum_types_by_name['RotationMode'] = _ROTATIONMODE
    DESCRIPTOR.enum_types_by_name['StructureType'] = _STRUCTURETYPE
    DESCRIPTOR.enum_types_by_name['InkType'] = _INKTYPE
    _sym_db.RegisterFileDescriptor(DESCRIPTOR)

    Rectangle = _reflection.GeneratedProtocolMessageType('Rectangle', (_message.Message,), {
      'DESCRIPTOR' : _RECTANGLE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Rectangle)
      })
    _sym_db.RegisterMessage(Rectangle)

    Matrix = _reflection.GeneratedProtocolMessageType('Matrix', (_message.Message,), {
      'DESCRIPTOR' : _MATRIX,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Matrix)
      })
    _sym_db.RegisterMessage(Matrix)

    Interval = _reflection.GeneratedProtocolMessageType('Interval', (_message.Message,), {
      'DESCRIPTOR' : _INTERVAL,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Interval)
      })
    _sym_db.RegisterMessage(Interval)

    PathPointProperties = _reflection.GeneratedProtocolMessageType('PathPointProperties', (_message.Message,), {
      'DESCRIPTOR' : _PATHPOINTPROPERTIES,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.PathPointProperties)
      })
    _sym_db.RegisterMessage(PathPointProperties)

    Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
      'DESCRIPTOR' : _PROPERTY,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Property)
      })
    _sym_db.RegisterMessage(Property)

    InputContext = _reflection.GeneratedProtocolMessageType('InputContext', (_message.Message,), {
      'DESCRIPTOR' : _INPUTCONTEXT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InputContext)
      })
    _sym_db.RegisterMessage(InputContext)

    Environment = _reflection.GeneratedProtocolMessageType('Environment', (_message.Message,), {
      'DESCRIPTOR' : _ENVIRONMENT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Environment)
      })
    _sym_db.RegisterMessage(Environment)

    InkInputProvider = _reflection.GeneratedProtocolMessageType('InkInputProvider', (_message.Message,), {
      'DESCRIPTOR' : _INKINPUTPROVIDER,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkInputProvider)
      })
    _sym_db.RegisterMessage(InkInputProvider)

    InputDevice = _reflection.GeneratedProtocolMessageType('InputDevice', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDEVICE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InputDevice)
      })
    _sym_db.RegisterMessage(InputDevice)

    SensorContext = _reflection.GeneratedProtocolMessageType('SensorContext', (_message.Message,), {
      'DESCRIPTOR' : _SENSORCONTEXT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.SensorContext)
      })
    _sym_db.RegisterMessage(SensorContext)

    SensorChannelsContext = _reflection.GeneratedProtocolMessageType('SensorChannelsContext', (_message.Message,), {
      'DESCRIPTOR' : _SENSORCHANNELSCONTEXT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.SensorChannelsContext)
      })
    _sym_db.RegisterMessage(SensorChannelsContext)

    SensorChannel = _reflection.GeneratedProtocolMessageType('SensorChannel', (_message.Message,), {
      'DESCRIPTOR' : _SENSORCHANNEL,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.SensorChannel)
      })
    _sym_db.RegisterMessage(SensorChannel)

    InputContextData = _reflection.GeneratedProtocolMessageType('InputContextData', (_message.Message,), {
      'DESCRIPTOR' : _INPUTCONTEXTDATA,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InputContextData)
      })
    _sym_db.RegisterMessage(InputContextData)

    ChannelData = _reflection.GeneratedProtocolMessageType('ChannelData', (_message.Message,), {
      'DESCRIPTOR' : _CHANNELDATA,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.ChannelData)
      })
    _sym_db.RegisterMessage(ChannelData)

    SensorData = _reflection.GeneratedProtocolMessageType('SensorData', (_message.Message,), {
      'DESCRIPTOR' : _SENSORDATA,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.SensorData)
      })
    _sym_db.RegisterMessage(SensorData)

    InputData = _reflection.GeneratedProtocolMessageType('InputData', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDATA,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InputData)
      })
    _sym_db.RegisterMessage(InputData)

    BrushPrototype = _reflection.GeneratedProtocolMessageType('BrushPrototype', (_message.Message,), {
      'DESCRIPTOR' : _BRUSHPROTOTYPE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.BrushPrototype)
      })
    _sym_db.RegisterMessage(BrushPrototype)

    VectorBrush = _reflection.GeneratedProtocolMessageType('VectorBrush', (_message.Message,), {
      'DESCRIPTOR' : _VECTORBRUSH,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.VectorBrush)
      })
    _sym_db.RegisterMessage(VectorBrush)

    RasterBrush = _reflection.GeneratedProtocolMessageType('RasterBrush', (_message.Message,), {
      'DESCRIPTOR' : _RASTERBRUSH,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.RasterBrush)
      })
    _sym_db.RegisterMessage(RasterBrush)

    Brushes = _reflection.GeneratedProtocolMessageType('Brushes', (_message.Message,), {
      'DESCRIPTOR' : _BRUSHES,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Brushes)
      })
    _sym_db.RegisterMessage(Brushes)

    Stroke = _reflection.GeneratedProtocolMessageType('Stroke', (_message.Message,), {

      'SplineData' : _reflection.GeneratedProtocolMessageType('SplineData', (_message.Message,), {
        'DESCRIPTOR' : _STROKE_SPLINEDATA,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.Stroke.SplineData)
        })
      ,

      'SplineCompressed' : _reflection.GeneratedProtocolMessageType('SplineCompressed', (_message.Message,), {
        'DESCRIPTOR' : _STROKE_SPLINECOMPRESSED,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.Stroke.SplineCompressed)
        })
      ,
      'DESCRIPTOR' : _STROKE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Stroke)
      })
    _sym_db.RegisterMessage(Stroke)
    _sym_db.RegisterMessage(Stroke.SplineData)
    _sym_db.RegisterMessage(Stroke.SplineCompressed)

    InkData = _reflection.GeneratedProtocolMessageType('InkData', (_message.Message,), {
      'DESCRIPTOR' : _INKDATA,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkData)
      })
    _sym_db.RegisterMessage(InkData)

    TripleStore = _reflection.GeneratedProtocolMessageType('TripleStore', (_message.Message,), {

      'SemanticTriple' : _reflection.GeneratedProtocolMessageType('SemanticTriple', (_message.Message,), {
        'DESCRIPTOR' : _TRIPLESTORE_SEMANTICTRIPLE,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.TripleStore.SemanticTriple)
        })
      ,
      'DESCRIPTOR' : _TRIPLESTORE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.TripleStore)
      })
    _sym_db.RegisterMessage(TripleStore)
    _sym_db.RegisterMessage(TripleStore.SemanticTriple)

    Properties = _reflection.GeneratedProtocolMessageType('Properties', (_message.Message,), {
      'DESCRIPTOR' : _PROPERTIES,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Properties)
      })
    _sym_db.RegisterMessage(Properties)

    Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
      'DESCRIPTOR' : _NODE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Node)
      })
    _sym_db.RegisterMessage(Node)

    InkTree = _reflection.GeneratedProtocolMessageType('InkTree', (_message.Message,), {
      'DESCRIPTOR' : _INKTREE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkTree)
      })
    _sym_db.RegisterMessage(InkTree)

    InkStructure = _reflection.GeneratedProtocolMessageType('InkStructure', (_message.Message,), {
      'DESCRIPTOR' : _INKSTRUCTURE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkStructure)
      })
    _sym_db.RegisterMessage(InkStructure)

    Path = _reflection.GeneratedProtocolMessageType('Path', (_message.Message,), {
      'DESCRIPTOR' : _PATH,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Path)
      })
    _sym_db.RegisterMessage(Path)

    Paths = _reflection.GeneratedProtocolMessageType('Paths', (_message.Message,), {
      'DESCRIPTOR' : _PATHS,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Paths)
      })
    _sym_db.RegisterMessage(Paths)

    InkPath = _reflection.GeneratedProtocolMessageType('InkPath', (_message.Message,), {
      'DESCRIPTOR' : _INKPATH,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkPath)
      })
    _sym_db.RegisterMessage(InkPath)

    Style = _reflection.GeneratedProtocolMessageType('Style', (_message.Message,), {
      'DESCRIPTOR' : _STYLE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Style)
      })
    _sym_db.RegisterMessage(Style)

    Segment = _reflection.GeneratedProtocolMessageType('Segment', (_message.Message,), {
      'DESCRIPTOR' : _SEGMENT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Segment)
      })
    _sym_db.RegisterMessage(Segment)

    StrokesContext = _reflection.GeneratedProtocolMessageType('StrokesContext', (_message.Message,), {
      'DESCRIPTOR' : _STROKESCONTEXT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.StrokesContext)
      })
    _sym_db.RegisterMessage(StrokesContext)

    Intersection = _reflection.GeneratedProtocolMessageType('Intersection', (_message.Message,), {
      'DESCRIPTOR' : _INTERSECTION,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Intersection)
      })
    _sym_db.RegisterMessage(Intersection)

    InkOperation = _reflection.GeneratedProtocolMessageType('InkOperation', (_message.Message,), {

      'Compose' : _reflection.GeneratedProtocolMessageType('Compose', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_COMPOSE,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Compose)
        })
      ,

      'Add' : _reflection.GeneratedProtocolMessageType('Add', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_ADD,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Add)
        })
      ,

      'Remove' : _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_REMOVE,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Remove)
        })
      ,

      'Update' : _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_UPDATE,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Update)
        })
      ,

      'Split' : _reflection.GeneratedProtocolMessageType('Split', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_SPLIT,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Split)
        })
      ,

      'Select' : _reflection.GeneratedProtocolMessageType('Select', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_SELECT,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Select)
        })
      ,

      'UpdateSelection' : _reflection.GeneratedProtocolMessageType('UpdateSelection', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_UPDATESELECTION,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.UpdateSelection)
        })
      ,

      'Transform' : _reflection.GeneratedProtocolMessageType('Transform', (_message.Message,), {
        'DESCRIPTOR' : _INKOPERATION_TRANSFORM,
        '__module__' : 'UIM_3_1_0_pb2'
        # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation.Transform)
        })
      ,
      'DESCRIPTOR' : _INKOPERATION,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkOperation)
      })
    _sym_db.RegisterMessage(InkOperation)
    _sym_db.RegisterMessage(InkOperation.Compose)
    _sym_db.RegisterMessage(InkOperation.Add)
    _sym_db.RegisterMessage(InkOperation.Remove)
    _sym_db.RegisterMessage(InkOperation.Update)
    _sym_db.RegisterMessage(InkOperation.Split)
    _sym_db.RegisterMessage(InkOperation.Select)
    _sym_db.RegisterMessage(InkOperation.UpdateSelection)
    _sym_db.RegisterMessage(InkOperation.Transform)

    Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), {
      'DESCRIPTOR' : _RANGE,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.Range)
      })
    _sym_db.RegisterMessage(Range)

    PathPointContext = _reflection.GeneratedProtocolMessageType('PathPointContext', (_message.Message,), {
      'DESCRIPTOR' : _PATHPOINTCONTEXT,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.PathPointContext)
      })
    _sym_db.RegisterMessage(PathPointContext)

    PathPointSettings = _reflection.GeneratedProtocolMessageType('PathPointSettings', (_message.Message,), {
      'DESCRIPTOR' : _PATHPOINTSETTINGS,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.PathPointSettings)
      })
    _sym_db.RegisterMessage(PathPointSettings)

    PropertySettings = _reflection.GeneratedProtocolMessageType('PropertySettings', (_message.Message,), {
      'DESCRIPTOR' : _PROPERTYSETTINGS,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.PropertySettings)
      })
    _sym_db.RegisterMessage(PropertySettings)

    InkTool = _reflection.GeneratedProtocolMessageType('InkTool', (_message.Message,), {
      'DESCRIPTOR' : _INKTOOL,
      '__module__' : 'UIM_3_1_0_pb2'
      # @@protoc_insertion_point(class_scope:UIM_3_1_0.InkTool)
      })
    _sym_db.RegisterMessage(InkTool)

    DESCRIPTOR._options = None
    # @@protoc_insertion_point(module_scope)

## Classes

`class BrushPrototype (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var coordX`

    Field UIM_3_1_0.BrushPrototype.coordX

  `var coordY`

    Field UIM_3_1_0.BrushPrototype.coordY

  `var coordZ`

    Field UIM_3_1_0.BrushPrototype.coordZ

  `var indices`

    Field UIM_3_1_0.BrushPrototype.indices

  `var shapeURI`

    Field UIM_3_1_0.BrushPrototype.shapeURI

  `var size`

    Field UIM_3_1_0.BrushPrototype.size

`class Brushes (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var rasterBrushes`

    Field UIM_3_1_0.Brushes.rasterBrushes

  `var vectorBrushes`

    Field UIM_3_1_0.Brushes.vectorBrushes

`class ChannelData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var sensorChannelID`

    Field UIM_3_1_0.ChannelData.sensorChannelID

  `var values`

    Field UIM_3_1_0.ChannelData.values

`class Environment (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field UIM_3_1_0.Environment.id

  `var properties`

    Field UIM_3_1_0.Environment.properties

`class InkData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var brushURIs`

    Field UIM_3_1_0.InkData.brushURIs

  `var properties`

    Field UIM_3_1_0.InkData.properties

  `var renderModeURIs`

    Field UIM_3_1_0.InkData.renderModeURIs

  `var strokes`

    Field UIM_3_1_0.InkData.strokes

  `var transform`

    Field UIM_3_1_0.InkData.transform

  `var unitScaleFactor`

    Field UIM_3_1_0.InkData.unitScaleFactor

`class InkInputProvider (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field UIM_3_1_0.InkInputProvider.id

  `var properties`

    Field UIM_3_1_0.InkInputProvider.properties

  `var type`

    Field UIM_3_1_0.InkInputProvider.type

`class InkOperation (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var Add`

    A ProtocolMessage

  `var Compose`

    A ProtocolMessage

  `var DESCRIPTOR`
  `var Remove`

    A ProtocolMessage

  `var Select`

    A ProtocolMessage

  `var Split`

    A ProtocolMessage

  `var Transform`

    A ProtocolMessage

  `var Update`

    A ProtocolMessage

  `var UpdateSelection`

    A ProtocolMessage

  ### Instance variables

  `var add`

    Field UIM_3_1_0.InkOperation.add

  `var compose`

    Field UIM_3_1_0.InkOperation.compose

  `var remove`

    Field UIM_3_1_0.InkOperation.remove

  `var select`

    Field UIM_3_1_0.InkOperation.select

  `var split`

    Field UIM_3_1_0.InkOperation.split

  `var transform`

    Field UIM_3_1_0.InkOperation.transform

  `var update`

    Field UIM_3_1_0.InkOperation.update

  `var updateSelection`

    Field UIM_3_1_0.InkOperation.updateSelection

`class InkPath (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var layout`

    Field UIM_3_1_0.InkPath.layout

  `var path`

    Field UIM_3_1_0.InkPath.path

  `var paths`

    Field UIM_3_1_0.InkPath.paths

  `var pointProps`

    Field UIM_3_1_0.InkPath.pointProps

  `var type`

    Field UIM_3_1_0.InkPath.type

`class InkStructure (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var inkTree`

    Field UIM_3_1_0.InkStructure.inkTree

  `var type`

    Field UIM_3_1_0.InkStructure.type

  `var views`

    Field UIM_3_1_0.InkStructure.views

`class InkTool (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var blendMode`

    Field UIM_3_1_0.InkTool.blendMode

  `var context`

    Field UIM_3_1_0.InkTool.context

  `var rasterBrush`

    Field UIM_3_1_0.InkTool.rasterBrush

  `var vectorBrush`

    Field UIM_3_1_0.InkTool.vectorBrush

`class InkTree (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var name`

    Field UIM_3_1_0.InkTree.name

  `var tree`

    Field UIM_3_1_0.InkTree.tree

`class InputContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var environmentID`

    Field UIM_3_1_0.InputContext.environmentID

  `var id`

    Field UIM_3_1_0.InputContext.id

  `var sensorContextID`

    Field UIM_3_1_0.InputContext.sensorContextID

`class InputContextData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var environments`

    Field UIM_3_1_0.InputContextData.environments

  `var inkInputProviders`

    Field UIM_3_1_0.InputContextData.inkInputProviders

  `var inputContexts`

    Field UIM_3_1_0.InputContextData.inputContexts

  `var inputDevices`

    Field UIM_3_1_0.InputContextData.inputDevices

  `var sensorContexts`

    Field UIM_3_1_0.InputContextData.sensorContexts

`class InputData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var inputContextData`

    Field UIM_3_1_0.InputData.inputContextData

  `var sensorData`

    Field UIM_3_1_0.InputData.sensorData

`class InputDevice (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field UIM_3_1_0.InputDevice.id

  `var properties`

    Field UIM_3_1_0.InputDevice.properties

`class Intersection (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var intervals`

    Field UIM_3_1_0.Intersection.intervals

  `var path`

    Field UIM_3_1_0.Intersection.path

`class Interval (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var fromIndex`

    Field UIM_3_1_0.Interval.fromIndex

  `var fromTValue`

    Field UIM_3_1_0.Interval.fromTValue

  `var id`

    Field UIM_3_1_0.Interval.id

  `var toIndex`

    Field UIM_3_1_0.Interval.toIndex

  `var toTValue`

    Field UIM_3_1_0.Interval.toTValue

`class Matrix (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var m00`

    Field UIM_3_1_0.Matrix.m00

  `var m01`

    Field UIM_3_1_0.Matrix.m01

  `var m02`

    Field UIM_3_1_0.Matrix.m02

  `var m03`

    Field UIM_3_1_0.Matrix.m03

  `var m10`

    Field UIM_3_1_0.Matrix.m10

  `var m11`

    Field UIM_3_1_0.Matrix.m11

  `var m12`

    Field UIM_3_1_0.Matrix.m12

  `var m13`

    Field UIM_3_1_0.Matrix.m13

  `var m20`

    Field UIM_3_1_0.Matrix.m20

  `var m21`

    Field UIM_3_1_0.Matrix.m21

  `var m22`

    Field UIM_3_1_0.Matrix.m22

  `var m23`

    Field UIM_3_1_0.Matrix.m23

  `var m30`

    Field UIM_3_1_0.Matrix.m30

  `var m31`

    Field UIM_3_1_0.Matrix.m31

  `var m32`

    Field UIM_3_1_0.Matrix.m32

  `var m33`

    Field UIM_3_1_0.Matrix.m33

`class Node (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var bounds`

    Field UIM_3_1_0.Node.bounds

  `var depth`

    Field UIM_3_1_0.Node.depth

  `var groupID`

    Field UIM_3_1_0.Node.groupID

  `var index`

    Field UIM_3_1_0.Node.index

  `var interval`

    Field UIM_3_1_0.Node.interval

`class Path (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var data`

    Field UIM_3_1_0.Path.data

`class PathPointContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var colorMask`

    Field UIM_3_1_0.PathPointContext.colorMask

  `var dynamics`

    Field UIM_3_1_0.PathPointContext.dynamics

  `var statics`

    Field UIM_3_1_0.PathPointContext.statics

`class PathPointProperties (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var color`

    Field UIM_3_1_0.PathPointProperties.color

  `var offsetX`

    Field UIM_3_1_0.PathPointProperties.offsetX

  `var offsetY`

    Field UIM_3_1_0.PathPointProperties.offsetY

  `var offsetZ`

    Field UIM_3_1_0.PathPointProperties.offsetZ

  `var rotation`

    Field UIM_3_1_0.PathPointProperties.rotation

  `var scaleX`

    Field UIM_3_1_0.PathPointProperties.scaleX

  `var scaleY`

    Field UIM_3_1_0.PathPointProperties.scaleY

  `var scaleZ`

    Field UIM_3_1_0.PathPointProperties.scaleZ

  `var size`

    Field UIM_3_1_0.PathPointProperties.size

`class PathPointSettings (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var alpha`

    Field UIM_3_1_0.PathPointSettings.alpha

  `var blue`

    Field UIM_3_1_0.PathPointSettings.blue

  `var green`

    Field UIM_3_1_0.PathPointSettings.green

  `var offsetX`

    Field UIM_3_1_0.PathPointSettings.offsetX

  `var offsetY`

    Field UIM_3_1_0.PathPointSettings.offsetY

  `var offsetZ`

    Field UIM_3_1_0.PathPointSettings.offsetZ

  `var red`

    Field UIM_3_1_0.PathPointSettings.red

  `var rotation`

    Field UIM_3_1_0.PathPointSettings.rotation

  `var scaleX`

    Field UIM_3_1_0.PathPointSettings.scaleX

  `var scaleY`

    Field UIM_3_1_0.PathPointSettings.scaleY

  `var scaleZ`

    Field UIM_3_1_0.PathPointSettings.scaleZ

  `var size`

    Field UIM_3_1_0.PathPointSettings.size

`class Paths (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var data`

    Field UIM_3_1_0.Paths.data

`class Properties (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var properties`

    Field UIM_3_1_0.Properties.properties

`class Property (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var name`

    Field UIM_3_1_0.Property.name

  `var value`

    Field UIM_3_1_0.Property.value

`class PropertySettings (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var altitude`

    Field UIM_3_1_0.PropertySettings.altitude

  `var dependencies`

    Field UIM_3_1_0.PropertySettings.dependencies

  `var pressure`

    Field UIM_3_1_0.PropertySettings.pressure

  `var radiusX`

    Field UIM_3_1_0.PropertySettings.radiusX

  `var radiusY`

    Field UIM_3_1_0.PropertySettings.radiusY

  `var resolveURI`

    Field UIM_3_1_0.PropertySettings.resolveURI

  `var value`

    Field UIM_3_1_0.PropertySettings.value

  `var velocity`

    Field UIM_3_1_0.PropertySettings.velocity

`class Range (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var max`

    Field UIM_3_1_0.Range.max

  `var min`

    Field UIM_3_1_0.Range.min

  `var remapURI`

    Field UIM_3_1_0.Range.remapURI

`class RasterBrush (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var blendMode`

    Field UIM_3_1_0.RasterBrush.blendMode

  `var fillHeight`

    Field UIM_3_1_0.RasterBrush.fillHeight

  `var fillTexture`

    Field UIM_3_1_0.RasterBrush.fillTexture

  `var fillTextureURI`

    Field UIM_3_1_0.RasterBrush.fillTextureURI

  `var fillWidth`

    Field UIM_3_1_0.RasterBrush.fillWidth

  `var name`

    Field UIM_3_1_0.RasterBrush.name

  `var randomizeFill`

    Field UIM_3_1_0.RasterBrush.randomizeFill

  `var rotationMode`

    Field UIM_3_1_0.RasterBrush.rotationMode

  `var scattering`

    Field UIM_3_1_0.RasterBrush.scattering

  `var shapeTexture`

    Field UIM_3_1_0.RasterBrush.shapeTexture

  `var shapeTextureURI`

    Field UIM_3_1_0.RasterBrush.shapeTextureURI

  `var spacing`

    Field UIM_3_1_0.RasterBrush.spacing

`class Rectangle (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var height`

    Field UIM_3_1_0.Rectangle.height

  `var width`

    Field UIM_3_1_0.Rectangle.width

  `var x`

    Field UIM_3_1_0.Rectangle.x

  `var y`

    Field UIM_3_1_0.Rectangle.y

`class Segment (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var complete`

    Field UIM_3_1_0.Segment.complete

  `var ink`

    Field UIM_3_1_0.Segment.ink

  `var pointerID`

    Field UIM_3_1_0.Segment.pointerID

`class SensorChannel (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field UIM_3_1_0.SensorChannel.id

  `var max`

    Field UIM_3_1_0.SensorChannel.max

  `var metric`

    Field UIM_3_1_0.SensorChannel.metric

  `var min`

    Field UIM_3_1_0.SensorChannel.min

  `var precision`

    Field UIM_3_1_0.SensorChannel.precision

  `var resolution`

    Field UIM_3_1_0.SensorChannel.resolution

  `var type`

    Field UIM_3_1_0.SensorChannel.type

`class SensorChannelsContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var channels`

    Field UIM_3_1_0.SensorChannelsContext.channels

  `var id`

    Field UIM_3_1_0.SensorChannelsContext.id

  `var inkInputProviderID`

    Field UIM_3_1_0.SensorChannelsContext.inkInputProviderID

  `var inputDeviceID`

    Field UIM_3_1_0.SensorChannelsContext.inputDeviceID

  `var latency`

    Field UIM_3_1_0.SensorChannelsContext.latency

  `var samplingRateHint`

    Field UIM_3_1_0.SensorChannelsContext.samplingRateHint

`class SensorContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field UIM_3_1_0.SensorContext.id

  `var sensorChannelsContext`

    Field UIM_3_1_0.SensorContext.sensorChannelsContext

`class SensorData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var dataChannels`

    Field UIM_3_1_0.SensorData.dataChannels

  `var id`

    Field UIM_3_1_0.SensorData.id

  `var inputContextID`

    Field UIM_3_1_0.SensorData.inputContextID

  `var state`

    Field UIM_3_1_0.SensorData.state

  `var timestamp`

    Field UIM_3_1_0.SensorData.timestamp

`class Stroke (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`
  `var SplineCompressed`

    A ProtocolMessage

  `var SplineData`

    A ProtocolMessage

  ### Instance variables

  `var brushURIIndex`

    Field UIM_3_1_0.Stroke.brushURIIndex

  `var brushURIValue`

    Field UIM_3_1_0.Stroke.brushURIValue

  `var endParameter`

    Field UIM_3_1_0.Stroke.endParameter

  `var id`

    Field UIM_3_1_0.Stroke.id

  `var precisions`

    Field UIM_3_1_0.Stroke.precisions

  `var propertiesIndex`

    Field UIM_3_1_0.Stroke.propertiesIndex

  `var propertiesValue`

    Field UIM_3_1_0.Stroke.propertiesValue

  `var randomSeed`

    Field UIM_3_1_0.Stroke.randomSeed

  `var renderModeURIIndex`

    Field UIM_3_1_0.Stroke.renderModeURIIndex

  `var renderModeURIValue`

    Field UIM_3_1_0.Stroke.renderModeURIValue

  `var sensorDataID`

    Field UIM_3_1_0.Stroke.sensorDataID

  `var sensorDataMapping`

    Field UIM_3_1_0.Stroke.sensorDataMapping

  `var sensorDataOffset`

    Field UIM_3_1_0.Stroke.sensorDataOffset

  `var splineCompressed`

    Field UIM_3_1_0.Stroke.splineCompressed

  `var splineData`

    Field UIM_3_1_0.Stroke.splineData

  `var startParameter`

    Field UIM_3_1_0.Stroke.startParameter

`class StrokesContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var path`

    Field UIM_3_1_0.StrokesContext.path

`class Style (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var brushURI`

    Field UIM_3_1_0.Style.brushURI

  `var color`

    Field UIM_3_1_0.Style.color

  `var pointerID`

    Field UIM_3_1_0.Style.pointerID

  `var randomSeed`

    Field UIM_3_1_0.Style.randomSeed

  `var renderModeURI`

    Field UIM_3_1_0.Style.renderModeURI

`class TripleStore (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`
  `var SemanticTriple`

    A ProtocolMessage

  ### Instance variables

  `var statements`

    Field UIM_3_1_0.TripleStore.statements

`class VectorBrush (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var name`

    Field UIM_3_1_0.VectorBrush.name

  `var prototype`

    Field UIM_3_1_0.VectorBrush.prototype

  `var spacing`

    Field UIM_3_1_0.VectorBrush.spacing